@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru">
 <context>
     <name>IncDecVolumeCommandLineOption</name>
     <message>
-        <location filename="../incdecvolumeoption.cpp" line="23"/>
+        <location filename="../incdecvolumeoption.cpp" line="44"/>
         <source>Increase volume with step 5</source>
         <translation>Увеличить громкость на 5 единиц</translation>
     </message>
     <message>
-        <location filename="../incdecvolumeoption.cpp" line="24"/>
+        <location filename="../incdecvolumeoption.cpp" line="45"/>
         <source>Decrease volume with step 5</source>
         <translation>Уменьшить громкость на 5 единиц</translation>
     </message>
