@@ -6,7 +6,7 @@
     <message>
         <location filename="../seekoption.cpp" line="38"/>
         <source>Seek to position in the current track</source>
-        <translation type="unfinished">Zu Position im derzeitigen Stück spulen</translation>
+        <translation>Zu Position im derzeitigen Stück spulen</translation>
     </message>
     <message>
         <location filename="../seekoption.cpp" line="39"/>
