@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2008 by Ilya Kotov                                      *
+*   Copyright (C) 2008-2012 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -32,7 +32,6 @@ class QmmpFileDialog : public FileDialog
 public:
     QmmpFileDialog();
     virtual ~QmmpFileDialog();
-    bool modal()const;
 
     void raise(const QString &dir = QString(),
                Mode mode = AddFiles,
@@ -74,7 +73,7 @@ private:
 class QmmpFileDialogFactory : public QObject, public FileDialogFactory
 {
     Q_OBJECT
-    Q_INTERFACES(FileDialogFactory);
+    Q_INTERFACES(FileDialogFactory)
 public:
     virtual FileDialog* create();
     virtual const FileDialogProperties properties() const;
