@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,33 +15,32 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QAction>
 #include <QApplication>
 #include <QMessageBox>
-#include <qmmpui/generalhandler.h>
+#include <qmmpui/uihelper.h>
 #include <qmmpui/playlistmodel.h>
 #include <qmmpui/playlistitem.h>
 #include <qmmpui/mediaplayer.h>
-#include <qmmpui/generalhandler.h>
 #include <qmmpui/metadataformatter.h>
 #include <qmmp/metadatamanager.h>
 #include "coverwidget.h"
 #include "covermanager.h"
 
-CoverManager::CoverManager(QObject *parent) : General(parent)
+CoverManager::CoverManager(QObject *parent) : QObject(parent)
 {
     m_action = new QAction(tr("Show Cover"), this);
     m_action->setShortcut(tr("Ctrl+M"));
-    GeneralHandler::instance()->addAction(m_action, GeneralHandler::PLAYLIST_MENU);
+    UiHelper::instance()->addAction(m_action, UiHelper::PLAYLIST_MENU);
     connect (m_action, SIGNAL(triggered ()), SLOT(showWindow()));
 }
 
 void CoverManager::showWindow()
 {
-    QList <PlayListItem *> items = MediaPlayer::instance()->playListManager()->selectedPlayList()->getSelectedItems();
+    QList <PlayListItem *> items = MediaPlayer::instance()->playListManager()->selectedPlayList()->selectedItems();
     if (!items.isEmpty())
     {
         CoverWidget *w = new CoverWidget(qApp->activeWindow ());
