@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include <QTextCodec>
 #include <QSettings>
@@ -24,6 +24,7 @@
 #include <QMenu>
 #include <QHeaderView>
 #include <QApplication>
+#include <QDesktopServices>
 #include <qmmp/qmmp.h>
 #include <qmmpui/filedialog.h>
 #include "fileops.h"
@@ -136,8 +137,8 @@ void SettingsDialog::createAction()
     comboBox->setFocusPolicy (Qt::NoFocus);
 
     ActionItem *item = new ActionItem(tr("New action"));
-    //item->setPattern(settings.value(QString("pattern_%1").arg(i)).toString());
-    //item->setDestination(settings.value(QString("destination_%1").arg(i)).toString());
+    item->setDestination(QDesktopServices::storageLocation(QDesktopServices::MusicLocation));
+    item->setPattern("%p - %t");
 
     ui.tableWidget->setCellWidget (row, 0, checkBox);
     ui.tableWidget->setCellWidget (row, 1, comboBox);
