@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,14 +15,14 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtDBus>
 #include <QActionGroup>
 #include <QApplication>
 #include <QStyle>
-#include <qmmpui/generalhandler.h>
+#include <qmmpui/uihelper.h>
 #include <qmmpui/mediaplayer.h>
 #include <qmmpui/playlistmanager.h>
 #include <qmmpui/playlistitem.h>
@@ -31,8 +31,7 @@
 #include "halmanager.h"
 #include "halplugin.h"
 
-HalPlugin::HalPlugin(QObject *parent)
-        : General(parent)
+HalPlugin::HalPlugin(QObject *parent) : QObject(parent)
 {
     m_manager = new HalManager(this);
     m_actions = new QActionGroup(this);
@@ -58,7 +57,6 @@ HalPlugin::HalPlugin(QObject *parent)
     settings.endGroup();
 }
 
-
 HalPlugin::~HalPlugin()
 {
 }
@@ -181,7 +179,7 @@ void HalPlugin::updateActions()
                 action->setIcon(qApp->style()->standardIcon(QStyle::SP_DriveHDIcon));
 
             m_actions->addAction(action);
-            GeneralHandler::instance()->addAction(action, GeneralHandler::TOOLS_MENU);
+            UiHelper::instance()->addAction(action, UiHelper::TOOLS_MENU);
             addPath(dev_path);
         }
     }
@@ -191,7 +189,7 @@ void HalPlugin::updateActions()
         if (!findDevice(action))
         {
             m_actions->removeAction(action);
-            GeneralHandler::instance()->removeAction(action);
+            UiHelper::instance()->removeAction(action);
             removePath(action->data().toString());
             action->deleteLater();
         }
