@@ -40,22 +40,22 @@
         <translation>Nastavení notifikačního modulu</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="141"/>
+        <location filename="../settingsdialog.ui" line="75"/>
         <source>Transparency:</source>
         <translation>Průhlednost:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="105"/>
+        <location filename="../settingsdialog.cpp" line="107"/>
         <source>Notification Template</source>
         <translation>Šablona notifikace</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="368"/>
+        <location filename="../settingsdialog.ui" line="378"/>
         <source>Psi Notification</source>
         <translation>Notifikace v Psi</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="380"/>
+        <location filename="../settingsdialog.ui" line="390"/>
         <source>Enable Psi notification</source>
         <translation>Povolit notifikaci v Psi</translation>
     </message>
@@ -65,50 +65,55 @@
         <translation>Notifikace na pracovní ploše</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="55"/>
+        <location filename="../settingsdialog.ui" line="41"/>
         <source>Font:</source>
         <translation>Písmo:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="108"/>
+        <location filename="../settingsdialog.ui" line="299"/>
         <source>Cover size:</source>
         <translation>Velikost obalu:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="82"/>
+        <location filename="../settingsdialog.ui" line="332"/>
         <source>Delay (ms):</source>
         <translation>Prodleva (ms):</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="321"/>
+        <location filename="../settingsdialog.ui" line="219"/>
         <source>Position</source>
         <translation>Umístění</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="75"/>
+        <location filename="../settingsdialog.ui" line="61"/>
         <source>...</source>
         <translation>…</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../settingsdialog.ui" line="361"/>
+        <source>Playback resume notification</source>
+        <translation>Oznámení o pokračování přehrávání</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="368"/>
         <source>Song change notification</source>
         <translation>Upozornění na změnu skladby</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="48"/>
+        <location filename="../settingsdialog.ui" line="325"/>
         <source>Volume change notification</source>
         <translation>Upozornění na změnu hlasitosti</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="134"/>
-        <location filename="../settingsdialog.ui" line="164"/>
+        <location filename="../settingsdialog.ui" line="68"/>
+        <location filename="../settingsdialog.ui" line="279"/>
         <source>0</source>
         <translation>0</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="343"/>
+        <location filename="../settingsdialog.ui" line="241"/>
         <source>Edit template</source>
-        <translation type="unfinished"></translation>
+        <translation>Upravit šablonu</translation>
     </message>
 </context>
 </TS>
