@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,29 +15,26 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#define SCROBBLER_LIBREFM_URL "turtle.libre.fm"
-#define SCROBBLER_LASTFM_URL "ws.audioscrobbler.com/2.0"
-
 #include <QSettings>
-#include "scrobbler.h"
-#include "scrobbler2.h"
+#include "lastfmscrobbler.h"
+#include "librefmscrobbler.h"
 #include "scrobblerhandler.h"
 
-ScrobblerHandler::ScrobblerHandler(QObject *parent) : General(parent)
+ScrobblerHandler::ScrobblerHandler(QObject *parent) : QObject(parent)
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.beginGroup("Scrobbler");
     if(settings.value("use_lastfm", false).toBool())
     {
-        new Scrobbler2(SCROBBLER_LASTFM_URL, "lastfm", this);
+        new LastfmScrobbler(this);
     }
     if(settings.value("use_librefm", false).toBool())
     {
-        new Scrobbler(SCROBBLER_LIBREFM_URL, settings.value("librefm_login").toString(),
-                   settings.value("librefm_password").toString(), "librefm", this);
+        new LibrefmScrobbler(settings.value("librefm_login").toString(),
+                             settings.value("librefm_password").toString(), this);
 
     }
     settings.endGroup();
