@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Ilya Kotov                                      *
+ *   Copyright (C) 2008-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QMenu>
@@ -27,46 +27,52 @@
 #include <QEvent>
 #include <QStyle>
 #include <QApplication>
-
 #include <qmmp/soundcore.h>
 #include <qmmpui/mediaplayer.h>
-
+#include <qmmpui/uihelper.h>
+#include <qmmpui/metadataformatter.h>
 #include "qmmptrayicon.h"
 #include "statusicon.h"
 
-StatusIcon::StatusIcon(QObject *parent)
-        : General(parent)
+StatusIcon::StatusIcon(QObject *parent) : QObject(parent)
 {
     m_tray = new QmmpTrayIcon(this);
-    connect(m_tray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(trayActivated(QSystemTrayIcon::ActivationReason)));
+    connect(m_tray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(trayActivated(QSystemTrayIcon::ActivationReason)));
     //m_tray->show();
     m_core = SoundCore::instance();
     m_player = MediaPlayer::instance();
-    QMenu *menu = new QMenu(qobject_cast<QWidget *>(parent));
-    menu->addAction(tr("Play"), m_player, SLOT(play()));
-    menu->addAction(tr("Pause"), m_core, SLOT(pause()));
-    menu->addAction(tr("Stop"), m_core, SLOT(stop()));
-    menu->addAction(tr("Next"), m_player, SLOT(next()));
-    menu->addAction(tr("Previous"), m_player, SLOT(previous()));
-    menu->addSeparator();
-    menu->addAction(tr("Exit"), this, SLOT(exit()));
-    m_tray->setContextMenu(menu);
-
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.beginGroup("Tray");
-    m_showMessage = settings.value("show_message",TRUE).toBool();
+    m_showMessage = settings.value("show_message",true).toBool();
     m_messageDelay = settings.value("message_delay", 2000).toInt();
-    m_showTooltip = settings.value("show_tooltip",FALSE).toBool();
-    m_hideToTray = settings.value("hide_on_close", FALSE).toBool();
-    m_useStandardIcons = settings.value("use_standard_icons",FALSE).toBool();
-#if QT_VERSION >= 0x040400
+    m_hideToTray = settings.value("hide_on_close", false).toBool();
+    m_useStandardIcons = settings.value("use_standard_icons",false).toBool();
+    m_tooltip = settings.value("show_tooltip",true).toBool();
+#ifdef Q_WS_X11
+    m_tray->showNiceToolTip(m_tooltip);
+#endif
     if(m_useStandardIcons)
         m_tray->setIcon(QApplication::style ()->standardIcon(QStyle::SP_MediaStop));
     else
-#endif
-        m_tray->setIcon ( QIcon(":/tray_stop.png"));
+        m_tray->setIcon(QIcon(":/tray_stop.png"));
     m_tray->show();
     settings.endGroup();
+    //actions
+    m_menu = new QMenu();
+    QIcon playIcon = QApplication::style()->standardIcon(QStyle::SP_MediaPlay);
+    QIcon pauseIcon = QApplication::style()->standardIcon(QStyle::SP_MediaPause);
+    QIcon stopIcon = QApplication::style()->standardIcon(QStyle::SP_MediaStop);
+    QIcon nextIcon = QApplication::style()->standardIcon(QStyle::SP_MediaSkipForward);
+    QIcon previousIcon = QApplication::style()->standardIcon(QStyle::SP_MediaSkipBackward);
+    m_menu->addAction(playIcon,tr("Play"), m_player, SLOT(play()));
+    m_menu->addAction(pauseIcon,tr("Pause"), m_core, SLOT(pause()));
+    m_menu->addAction(stopIcon,tr("Stop"), m_core, SLOT(stop()));
+    m_menu->addSeparator();
+    m_menu->addAction(nextIcon, tr("Next"), m_player, SLOT(next()));
+    m_menu->addAction(previousIcon, tr("Previous"), m_player, SLOT(previous()));
+    m_menu->addSeparator();
+    m_menu->addAction(tr("Exit"), UiHelper::instance(), SLOT(exit()));
+    m_tray->setContextMenu(m_menu);
     connect (m_core, SIGNAL(metaDataChanged ()), SLOT(showMetaData()));
     connect (m_core, SIGNAL(stateChanged (Qmmp::State)), SLOT(setState(Qmmp::State)));
     setState(m_core->state()); //update state
@@ -74,9 +80,10 @@ StatusIcon::StatusIcon(QObject *parent)
         QTimer::singleShot(1500, this, SLOT(showMetaData()));
 }
 
-
 StatusIcon::~StatusIcon()
-{}
+{
+    delete m_menu;
+}
 
 void StatusIcon::setState(Qmmp::State state)
 {
@@ -84,32 +91,29 @@ void StatusIcon::setState(Qmmp::State state)
     {
     case Qmmp::Playing:
     {
-#if QT_VERSION >= 0x040400
          if(m_useStandardIcons)
             m_tray->setIcon(QApplication::style ()->standardIcon(QStyle::SP_MediaPlay));
         else
-#endif
-            m_tray->setIcon ( QIcon(":/tray_play.png"));
+            m_tray->setIcon (QIcon(":/tray_play.png"));
         break;
     }
     case Qmmp::Paused:
     {
-#if QT_VERSION >= 0x040400
          if(m_useStandardIcons)
             m_tray->setIcon(QApplication::style ()->standardIcon(QStyle::SP_MediaPause));
         else
-#endif
-            m_tray->setIcon ( QIcon(":/tray_pause.png"));
+            m_tray->setIcon (QIcon(":/tray_pause.png"));
         break;
     }
     case Qmmp::Stopped:
     {
-#if QT_VERSION >= 0x040400
         if(m_useStandardIcons)
             m_tray->setIcon(QApplication::style ()->standardIcon(QStyle::SP_MediaStop));
         else
+            m_tray->setIcon (QIcon(":/tray_stop.png"));
+#ifndef Q_WS_X11
+        m_tray->setToolTip("");
 #endif
-            m_tray->setIcon ( QIcon(":/tray_stop.png"));
         break;
     }
     }
@@ -117,23 +121,30 @@ void StatusIcon::setState(Qmmp::State state)
 
 void StatusIcon::showMetaData()
 {
-    QString message = m_core->metaData(Qmmp::ARTIST) + " - " + m_core->metaData(Qmmp::TITLE);
-    if (message.startsWith (" - ") || message.endsWith (" - "))
-        message.remove(" - ");
+    MetaDataFormatter f("%p%if(%p&%t, - ,)%t");
+    QString message = f.parse(m_core->metaData());
     if (message.isEmpty())
         message = m_core->metaData(Qmmp::URL).section('/',-1);
 
     if (m_showMessage)
         m_tray->showMessage (tr("Now Playing"), message,
                              QSystemTrayIcon::Information, m_messageDelay);
-    if (m_showTooltip)
-        m_tray->setToolTip(message);
+#ifndef Q_WS_X11
+    if(m_tooltip)
+    {
+        MetaDataFormatter f("%p%if(%p&%t, - ,)%t");
+        QString message = f.parse(m_core->metaData());
+        if(message.isEmpty())
+            message = m_core->metaData(Qmmp::URL).section('/',-1);
+        m_tray->setToolTip(f.parse(m_core->metaData()));
+    }
+#endif
 }
 
 void StatusIcon::trayActivated(QSystemTrayIcon::ActivationReason reason)
 {
     if (reason == QSystemTrayIcon::Trigger)
-        toggleVisibility();
+        UiHelper::instance()->toggleVisibility();
     else if (reason == QSystemTrayIcon::MiddleClick)
     {
         if (SoundCore::instance()->state() == Qmmp::Stopped)
