@@ -39,6 +39,11 @@
         <source>0</source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="225"/>
+        <source>Edit template</source>
+        <translation>Edytuj szablon</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="91"/>
         <source>Try to split file name when no tag</source>
@@ -54,11 +59,6 @@
         <source>32</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="225"/>
-        <source>Change template</source>
-        <translation>Zmień szablon</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="250"/>
         <source>Use standard icons</source>
@@ -127,7 +127,7 @@
     </message>
     <message>
         <location filename="../statusiconfactory.cpp" line="52"/>
-        <source>Writen by:</source>
+        <source>Written by:</source>
         <translation>Napisana przez:</translation>
     </message>
     <message>
