@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -46,7 +46,7 @@ const DecoderProperties DecoderAACFactory::properties() const
     properties.name = tr("AAC Plugin");
     properties.filters << "*.aac";
     properties.description = tr("AAC Files");
-    properties.contentTypes << "audio/aacp";
+    properties.contentTypes << "audio/aacp" << "audio/aac";
     properties.shortName = "aac";
     properties.hasAbout = true;
     properties.hasSettings = false;
