@@ -6,7 +6,7 @@
     <message>
         <location filename="../aacmetadatamodel.cpp" line="43"/>
         <source>Length</source>
-        <translation>長さ</translation>
+        <translation>演奏時間</translation>
     </message>
     <message>
         <location filename="../aacmetadatamodel.cpp" line="45"/>
@@ -42,27 +42,27 @@
 <context>
     <name>DecoderAACFactory</name>
     <message>
-        <location filename="../decoderaacfactory.cpp" line="45"/>
+        <location filename="../decoderaacfactory.cpp" line="46"/>
         <source>AAC Plugin</source>
         <translation>AAC プラグイン</translation>
     </message>
     <message>
-        <location filename="../decoderaacfactory.cpp" line="47"/>
+        <location filename="../decoderaacfactory.cpp" line="48"/>
         <source>AAC Files</source>
         <translation>AAC ファイル</translation>
     </message>
     <message>
-        <location filename="../decoderaacfactory.cpp" line="87"/>
+        <location filename="../decoderaacfactory.cpp" line="88"/>
         <source>About AAC Audio Plugin</source>
         <translation>AAC 音響プラグインについて</translation>
     </message>
     <message>
-        <location filename="../decoderaacfactory.cpp" line="88"/>
+        <location filename="../decoderaacfactory.cpp" line="89"/>
         <source>Qmmp AAC Audio Plugin</source>
         <translation>QMMP AAC 音響プラグイン</translation>
     </message>
     <message>
-        <location filename="../decoderaacfactory.cpp" line="89"/>
+        <location filename="../decoderaacfactory.cpp" line="90"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
