@@ -43,13 +43,16 @@
 
 #include "decoder_cdaudio.h"
 
-static void log_handler (cdio_log_level_t level, const char message[])
+QList <CDATrack> DecoderCDAudio::m_track_cache;
+
+static void log_handler (cdio_log_level_t level, const char *message)
 {
     QString str = QString::fromLocal8Bit(message).trimmed();
     switch (level)
     {
     case CDIO_LOG_DEBUG:
         qDebug("DecoderCDAudio: cdio message: %s (level=debug)", qPrintable(str));
+        return;
     case CDIO_LOG_INFO:
         qDebug("DecoderCDAudio: cdio message: %s (level=info)", qPrintable(str));
         return;
@@ -58,6 +61,22 @@ static void log_handler (cdio_log_level_t level, const char message[])
     }
 }
 
+static void cddb_log_handler(cddb_log_level_t level, const char *message)
+{
+    QString str = QString::fromLocal8Bit(message).trimmed();
+    switch (level)
+    {
+    case CDDB_LOG_DEBUG:
+        qDebug("DecoderCDAudio: cddb message: %s (level=debug)", qPrintable(str));
+        return;
+    case CDDB_LOG_INFO:
+        qDebug("DecoderCDAudio: cddb message: %s (level=info)", qPrintable(str));
+        return;
+    default:
+        qWarning("DecoderCDAudio: cddb message: %s (level=error)", qPrintable(str));
+    }
+}
+
 // Decoder class
 
 DecoderCDAudio::DecoderCDAudio(const QString &url) : Decoder()
@@ -73,7 +92,6 @@ DecoderCDAudio::DecoderCDAudio(const QString &url) : Decoder()
     m_buffer = new char[CDDA_BUFFER_SIZE];
 }
 
-
 DecoderCDAudio::~DecoderCDAudio()
 {
     m_bitrate = 0;
@@ -96,7 +114,7 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
     CdIo_t *cdio = 0;
     QString device_path = device;
     if (device_path.isEmpty() || device_path == "/")
-        device_path = settings.value("device").toString();
+        device_path = settings.value("cdaudio/device").toString();
     if (device_path.isEmpty() || device_path == "/")
     {
         char **cd_drives = cdio_get_devices_with_cap(0, CDIO_FS_AUDIO, true); //get drive list with CDA disks
@@ -133,6 +151,13 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
         qDebug("DecoderCDAudio: using cd audio capable drive \"%s\"", qPrintable(device_path));
     }
 
+    if(!m_track_cache.isEmpty() && !cdio_get_media_changed(cdio))
+    {
+        qDebug("DecoderCDAudio: using track cache...");
+        cdio_destroy(cdio);
+        return m_track_cache;
+    }
+
     if (cd_speed)
     {
         qDebug("DecoderCDAudio: setting drive speed to %dX.", cd_speed);
@@ -200,6 +225,7 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
     if(use_cddb)
     {
         qDebug("DecoderCDAudio: reading CDDB...");
+        cddb_log_set_handler(cddb_log_handler);
         cddb_conn_t *cddb_conn = cddb_new ();
         cddb_disc_t *cddb_disc = NULL;
         cddb_track_t *cddb_track = NULL;
@@ -210,25 +236,25 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
         {
             cddb_cache_disable (cddb_conn); //disable libcddb cache, use own cache implementation instead
             settings.beginGroup("cdaudio");
-            cddb_set_server_name (cddb_conn, settings.value("cddb_server", "freedb.org").toByteArray());
+            cddb_set_server_name (cddb_conn, settings.value("cddb_server", "freedb.org").toByteArray().constData());
             cddb_set_server_port (cddb_conn, settings.value("cddb_port", 8880).toInt());
 
-            if (QmmpSettings::instance()->isProxyEnabled())
-            {
-                QUrl proxy = QmmpSettings::instance()->proxy();
-                cddb_http_proxy_enable (cddb_conn);
-                cddb_set_http_proxy_server_name (cddb_conn, proxy.host().toAscii ());
-                cddb_set_http_proxy_server_port (cddb_conn, proxy.port());
-                if(QmmpSettings::instance()->useProxyAuth())
-                {
-                    cddb_set_http_proxy_username (cddb_conn, proxy.userName().toAscii());
-                    cddb_set_http_proxy_password (cddb_conn, proxy.password().toAscii());
-                }
-            }
-            else if (settings.value("cddb_http", false).toBool())
+            if (settings.value("cddb_http", false).toBool())
             {
                 cddb_http_enable (cddb_conn);
                 cddb_set_http_path_query (cddb_conn, settings.value("cddb_path").toByteArray());
+                if (QmmpSettings::instance()->isProxyEnabled())
+                {
+                    QUrl proxy = QmmpSettings::instance()->proxy();
+                    cddb_http_proxy_enable (cddb_conn);
+                    cddb_set_http_proxy_server_name (cddb_conn, proxy.host().toAscii ());
+                    cddb_set_http_proxy_server_port (cddb_conn, proxy.port());
+                    if(QmmpSettings::instance()->useProxyAuth())
+                    {
+                        cddb_set_http_proxy_username (cddb_conn, proxy.userName().toAscii());
+                        cddb_set_http_proxy_password (cddb_conn, proxy.password().toAscii());
+                    }
+                }
             }
             settings.endGroup();
 
@@ -244,29 +270,25 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
             }
 
             cddb_disc_calc_discid (cddb_disc);
-            qDebug ("DecoderCDAudio: disc id = %x", cddb_disc_get_discid (cddb_disc));
             uint id = cddb_disc_get_discid (cddb_disc);
+            qDebug ("DecoderCDAudio: disc id = %x", id);
+
 
-            int matches = 0;
             if(readFromCache(&tracks, id))
                 qDebug("DecoderCDAudio: using local cddb cache");
-            else if ((matches = cddb_query (cddb_conn, cddb_disc)) == -1)
-            {
-
-                qWarning ("DecoderCDAudio: unable to query the CDDB server, error: %s",
-                          cddb_error_str (cddb_errno(cddb_conn)));
-            }
-            else if (!matches)
-                qDebug ("DecoderCDAudio: no CDDB info found");
             else
             {
-                cddb_read(cddb_conn, cddb_disc);
-                if (cddb_errno (cddb_conn) != CDDB_ERR_OK)
+                int matches = cddb_query (cddb_conn, cddb_disc);
+                if(matches == -1)
                 {
-                    qWarning ("DecoderCDAudio: unable to read the CDDB info: %s",
+                    qWarning ("DecoderCDAudio: unable to query the CDDB server, error: %s",
                               cddb_error_str (cddb_errno(cddb_conn)));
                 }
-                else
+                else if(matches == 0)
+                {
+                    qDebug ("DecoderCDAudio: no CDDB info found");
+                }
+                else if(cddb_read(cddb_conn, cddb_disc))
                 {
                     for (int i = first_track_number; i <= last_track_number; ++i)
                     {
@@ -283,6 +305,11 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
                     }
                     saveToCache(tracks,  id);
                 }
+                else
+                {
+                    qWarning ("DecoderCDAudio: unable to read the CDDB info: %s",
+                              cddb_error_str (cddb_errno(cddb_conn)));
+                }
             }
         }
         if (cddb_disc)
@@ -294,6 +321,7 @@ QList <CDATrack> DecoderCDAudio::generateTrackList(const QString &device)
 
     cdio_destroy(cdio);
     cdio = 0;
+    m_track_cache = tracks;
     return tracks;
 }
 
@@ -344,14 +372,23 @@ qint64 DecoderCDAudio::calculateTrackLength(lsn_t startlsn, lsn_t endlsn)
     return ((endlsn - startlsn + 1) * 1000) / 75;
 }
 
+void DecoderCDAudio::clearTrackCache()
+{
+    m_track_cache.clear();
+}
+
 bool DecoderCDAudio::initialize()
 {
     m_bitrate = 0;
     m_totalTime = 0;
     //extract track from url
     int track_number = m_url.section("#", -1).toInt();
+    QString device_path = m_url;
+    device_path.remove("cdda://");
+    device_path.remove(QRegExp("#\\d+$"));
+
     track_number = qMax(track_number, 1);
-    QList <CDATrack> tracks = DecoderCDAudio::generateTrackList(QUrl(m_url).path()); //generate track list
+    QList <CDATrack> tracks = DecoderCDAudio::generateTrackList(device_path); //generate track list
     if (tracks.isEmpty())
     {
         qWarning("DecoderCDAudio: initialize failed");
@@ -371,13 +408,14 @@ bool DecoderCDAudio::initialize()
         return false;
     }
 
-    if (QUrl(m_url).path().isEmpty() || QUrl(m_url).path() == "/") //try default path from config
+    if (device_path.isEmpty() || device_path == "/") //try default path from config
     {
         QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-        m_url = QString("cdda://%1#%2").arg(settings.value("device").toString()).arg(track_number);
+        device_path = settings.value("cdaudio/device").toString();
+        m_url = QString("cdda://%1#%2").arg(device_path).arg(track_number);
     }
 
-    if (QUrl(m_url).path() == "/")
+    if (device_path.isEmpty() || device_path == "/")
     {
         char **cd_drives = cdio_get_devices_with_cap(0, CDIO_FS_AUDIO, true); //get drive list with CDA disks
         // open first audio capable cd drive
@@ -402,13 +440,13 @@ bool DecoderCDAudio::initialize()
     }
     else
     {
-        m_cdio = cdio_open_cd(QUrl(m_url).path().toAscii().constData());
+        m_cdio = cdio_open_cd(device_path.toAscii().constData());
         if (!m_cdio)
         {
             qWarning("DecoderCDAudio: failed to open CD.");
             return false;
         }
-        qDebug("DecoderCDAudio: using cd audio capable drive \"%s\"", QUrl(m_url).path().toAscii().constData());
+        qDebug("DecoderCDAudio: using cd audio capable drive \"%s\"", qPrintable(device_path));
     }
     configure(44100, 2, Qmmp::PCM_S16LE);
     m_bitrate = 1411;
