@@ -75,7 +75,7 @@ CUEParser::CUEParser(const QString &url)
     }
 #endif
     if(!codec)
-        codec = QTextCodec::codecForName(settings.value("encoding","ISO-8859-1").toByteArray ());
+        codec = QTextCodec::codecForName(settings.value("encoding","UTF-8").toByteArray ());
     if(!codec)
         codec = QTextCodec::codecForName("UTF-8");
     settings.endGroup();
@@ -187,6 +187,8 @@ CUEParser::CUEParser(const QString &url)
                 m_tracks[i]->info.setLength(l - m_tracks[i]->offset);
             else
                 m_tracks[i]->info.setLength(0);
+            qDeleteAll(f_list);
+            f_list.clear();
         }
     }
 }
