@@ -43,8 +43,8 @@
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="35"/>
-        <source>Automatic file detection</source>
-        <translation>Automatische Dateierkennung</translation>
+        <source>Load incorrect cue sheets if possible</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="45"/>
