@@ -43,8 +43,8 @@
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="35"/>
-        <source>Automatic file detection</source>
-        <translation>ファイルを自動検出</translation>
+        <source>Load incorrect cue sheets if possible</source>
+        <translation>CUE シートに間違いがあってもできるだけ読み込む</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="45"/>
