@@ -4,83 +4,75 @@
 <context>
     <name>DecoderFFmpegFactory</name>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="256"/>
+        <location filename="../decoderffmpegfactory.cpp" line="230"/>
         <source>About FFmpeg Audio Plugin</source>
         <translation>Acerca del módulo de audio FFmpeg</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="258"/>
+        <location filename="../decoderffmpegfactory.cpp" line="231"/>
         <source>Qmmp FFmpeg Audio Plugin</source>
         <translation>Módulo de audio FFmpeg para Qmmp</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="266"/>
+        <location filename="../decoderffmpegfactory.cpp" line="232"/>
+        <source>Compiled against:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="245"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="93"/>
+        <location filename="../decoderffmpegfactory.cpp" line="125"/>
         <source>FFmpeg Plugin</source>
         <translation>Módulo FFmpeg</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="95"/>
+        <location filename="../decoderffmpegfactory.cpp" line="127"/>
         <source>FFmpeg Formats</source>
         <translation>Formatos FFmpeg</translation>
     </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="259"/>
-        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
-        <translation>Compilado con libavformat-%1.%2.%3 y libavcodec-%4.%5.%6</translation>
-    </message>
 </context>
 <context>
     <name>FFmpegMetaDataModel</name>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="99"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="45"/>
         <source>Length</source>
         <translation>Duración</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="53"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="100"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="46"/>
         <source>File size</source>
         <translation>Tamaño del archivo</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="53"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="100"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="46"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="54"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="101"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="47"/>
         <source>Bitrate</source>
         <translation>Tasa de bits</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="54"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="101"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="47"/>
         <source>kbps</source>
         <translation>kbps</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="117"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
         <source>Sample rate</source>
         <translation>Frecuencia</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="117"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="67"/>
-        <location filename="../ffmpegmetadatamodel.cpp" line="118"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
         <source>Channels</source>
         <translation>Canales</translation>
     </message>
