@@ -4,27 +4,27 @@
 <context>
     <name>DecoderFLACFactory</name>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="51"/>
+        <location filename="../decoderflacfactory.cpp" line="57"/>
         <source>FLAC Plugin</source>
         <translation>FLAC 插件</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="53"/>
+        <location filename="../decoderflacfactory.cpp" line="59"/>
         <source>FLAC Files</source>
         <translation>FLAC 檔案</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="183"/>
+        <location filename="../decoderflacfactory.cpp" line="187"/>
         <source>About FLAC Audio Plugin</source>
         <translation>關於 FLAC 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="184"/>
+        <location filename="../decoderflacfactory.cpp" line="188"/>
         <source>Qmmp FLAC Audio Plugin</source>
         <translation>Qmmp FLAC 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decoderflacfactory.cpp" line="185"/>
+        <location filename="../decoderflacfactory.cpp" line="189"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -32,42 +32,42 @@
 <context>
     <name>FLACMetaDataModel</name>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="82"/>
+        <location filename="../flacmetadatamodel.cpp" line="80"/>
         <source>Length</source>
-        <translation type="unfinished"></translation>
+        <translation>長度</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="83"/>
+        <location filename="../flacmetadatamodel.cpp" line="81"/>
         <source>Sample rate</source>
-        <translation type="unfinished"></translation>
+        <translation>取樣率</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="83"/>
+        <location filename="../flacmetadatamodel.cpp" line="81"/>
         <source>Hz</source>
         <translation type="unfinished">Hz</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="84"/>
+        <location filename="../flacmetadatamodel.cpp" line="82"/>
         <source>Channels</source>
-        <translation type="unfinished"></translation>
+        <translation>聲音通道</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="85"/>
+        <location filename="../flacmetadatamodel.cpp" line="83"/>
         <source>Bitrate</source>
-        <translation type="unfinished"></translation>
+        <translation>比特率</translation>
+    </message>
+    <message>
+        <location filename="../flacmetadatamodel.cpp" line="83"/>
+        <source>kbps</source>
+        <translation>kbps</translation>
     </message>
     <message>
         <location filename="../flacmetadatamodel.cpp" line="85"/>
-        <source>kbps</source>
-        <translation type="unfinished">kbps</translation>
-    </message>
-    <message>
-        <location filename="../flacmetadatamodel.cpp" line="87"/>
         <source>File size</source>
-        <translation type="unfinished"></translation>
+        <translation>文件大小</translation>
     </message>
     <message>
-        <location filename="../flacmetadatamodel.cpp" line="87"/>
+        <location filename="../flacmetadatamodel.cpp" line="85"/>
         <source>KB</source>
         <translation type="unfinished">KB</translation>
     </message>
