@@ -35,8 +35,8 @@
     </message>
     <message>
         <location filename="../decodermadfactory.cpp" line="227"/>
-        <source>Source code based on mq3 progect</source>
-        <translation>Вихідний код базується на проекті mq3</translation>
+        <source>Source code based on mq3 and madplay projects</source>
+        <translation>Вихідні коди базуються на проектах mq3 та madplay</translation>
     </message>
 </context>
 <context>
@@ -151,7 +151,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
         <source>Tag Priority</source>
-        <translation>Приорітет тєгу</translation>
+        <translation>Пріоритет тегу</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
