@@ -26,7 +26,7 @@
     <message>
         <location filename="../decodermadfactory.cpp" line="222"/>
         <source>Compiled against libmad version:</source>
-        <translation>编译基于 libmad 的版本：</translation>
+        <translation>编译基于 libmad 版本：</translation>
     </message>
     <message>
         <location filename="../decodermadfactory.cpp" line="226"/>
@@ -35,8 +35,8 @@
     </message>
     <message>
         <location filename="../decodermadfactory.cpp" line="227"/>
-        <source>Source code based on mq3 progect</source>
-        <translation>源代码基于 mq3 项目</translation>
+        <source>Source code based on mq3 and madplay projects</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -44,27 +44,27 @@
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="70"/>
         <source>Format</source>
-        <translation type="unfinished"></translation>
+        <translation>格式</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="72"/>
         <source>Bitrate</source>
-        <translation type="unfinished"></translation>
+        <translation>比特率</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="72"/>
         <source>kbps</source>
-        <translation type="unfinished">kbps</translation>
-    </message>
-    <message>
-        <location filename="../mpegmetadatamodel.cpp" line="74"/>
-        <source>Sample rate</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mpegmetadatamodel.cpp" line="74"/>
+        <source>Sample rate</source>
+        <translation>取样率</translation>
+    </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="74"/>
         <source>Hz</source>
-        <translation type="unfinished">Hz</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="78"/>
@@ -72,49 +72,49 @@
         <location filename="../mpegmetadatamodel.cpp" line="84"/>
         <location filename="../mpegmetadatamodel.cpp" line="87"/>
         <source>Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>风格</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="90"/>
         <source>KB</source>
-        <translation type="unfinished">KB</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="91"/>
         <source>File size</source>
-        <translation type="unfinished"></translation>
+        <translation>文件大小</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="93"/>
         <location filename="../mpegmetadatamodel.cpp" line="95"/>
         <source>Protection</source>
-        <translation type="unfinished"></translation>
+        <translation>保护</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="93"/>
         <location filename="../mpegmetadatamodel.cpp" line="97"/>
         <location filename="../mpegmetadatamodel.cpp" line="101"/>
         <source>Yes</source>
-        <translation type="unfinished">是</translation>
+        <translation>是</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="95"/>
         <location filename="../mpegmetadatamodel.cpp" line="99"/>
         <location filename="../mpegmetadatamodel.cpp" line="103"/>
         <source>No</source>
-        <translation type="unfinished">否</translation>
+        <translation>否</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="97"/>
         <location filename="../mpegmetadatamodel.cpp" line="99"/>
         <source>Copyright</source>
-        <translation type="unfinished"></translation>
+        <translation>版权</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="101"/>
         <location filename="../mpegmetadatamodel.cpp" line="103"/>
         <source>Original</source>
-        <translation type="unfinished"></translation>
+        <translation>原创</translation>
     </message>
 </context>
 <context>
