@@ -26,7 +26,7 @@
     <message>
         <location filename="../decodermodplugfactory.cpp" line="129"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
         <location filename="../decodermodplugfactory.cpp" line="130"/>
@@ -79,7 +79,7 @@
     <message>
         <location filename="../modplugmetadatamodel.cpp" line="149"/>
         <source>Tempo</source>
-        <translation>Tempo</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../modplugmetadatamodel.cpp" line="150"/>
@@ -129,12 +129,12 @@
     <message>
         <location filename="../settingsdialog.ui" line="51"/>
         <source>16 bit</source>
-        <translation>16 bit</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="58"/>
         <source>8 bit</source>
-        <translation>8 bit</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="74"/>
@@ -144,7 +144,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="80"/>
         <source>Stereo</source>
-        <translation>Stereo</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="87"/>
@@ -154,7 +154,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="103"/>
         <source>Resampling</source>
-        <translation>Resampling</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="109"/>
@@ -184,22 +184,22 @@
     <message>
         <location filename="../settingsdialog.ui" line="152"/>
         <source>48000 Hz</source>
-        <translation>48000 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="159"/>
         <source>44100 Hz</source>
-        <translation>44100 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="166"/>
         <source>22050 Hz</source>
-        <translation>22050 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="173"/>
         <source>11025 Hz</source>
-        <translation>11025 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="184"/>
@@ -223,7 +223,7 @@
         <location filename="../settingsdialog.ui" line="499"/>
         <location filename="../settingsdialog.ui" line="618"/>
         <source>0</source>
-        <translation>0</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="260"/>
@@ -234,12 +234,12 @@
     <message>
         <location filename="../settingsdialog.ui" line="292"/>
         <source>40</source>
-        <translation>40</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="324"/>
         <source>Bass Boost</source>
-        <translation>Bass Boost</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="336"/>
@@ -254,17 +254,17 @@
     <message>
         <location filename="../settingsdialog.ui" line="426"/>
         <source>10</source>
-        <translation>10</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="458"/>
         <source>Surround</source>
-        <translation>Surround</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="551"/>
         <source>5</source>
-        <translation>5</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="577"/>
@@ -274,14 +274,15 @@
     <message>
         <location filename="../settingsdialog.ui" line="586"/>
         <source>Volume</source>
-        <translation>Volume</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="656"/>
         <source>Note: Setting the preamp
 too high may cause clipping!</source>
-        <translation>Notitie: Het instellvan de de voorversterking
-kan voor veel &apos;afsnijding&apos; zorgen</translation>
+        <translation>Notitie: Het te hoog instellen van
+de voorverstelling kan veel
+stotteringen veroorzaken!</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="671"/>
@@ -296,7 +297,7 @@ kan voor veel &apos;afsnijding&apos; zorgen</translation>
     <message>
         <location filename="../settingsdialog.ui" line="683"/>
         <source>Use filename as song title</source>
-        <translation>Gebruik bestandsnaam als liednaam</translation>
+        <translation>Gebruik bestandsnaam als nummertitel</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="690"/>
