@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -36,8 +36,20 @@ bool DecoderMPCFactory::supports(const QString &source) const
     return (source.right(4).toLower() == ".mpc");
 }
 
-bool DecoderMPCFactory::canDecode(QIODevice *) const
+bool DecoderMPCFactory::canDecode(QIODevice *input) const
 {
+    char buf[36];
+    if (input->peek(buf, 4) != 4)
+        return false;
+
+    if(!memcmp(buf, "MP+", 3))
+            return true;
+
+#ifndef MPC_OLD_API
+    if(!memcmp(buf, "MPCK", 4))
+        return true;
+#endif
+
     return false;
 }
 
@@ -63,7 +75,7 @@ QList<FileInfo *> DecoderMPCFactory::createPlayList(const QString &fileName, boo
 {
     FileInfo *info = new FileInfo(fileName);
 
-    TagLib::MPC::File fileRef(fileName.toLocal8Bit ());
+    TagLib::MPC::File fileRef(fileName.toLocal8Bit().constData());
     TagLib::APE::Tag *tag = useMetaData ? fileRef.APETag() : 0;
     if (tag && !tag->isEmpty())
     {
