@@ -4,27 +4,27 @@
 <context>
     <name>DecoderMPCFactory</name>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="47"/>
+        <location filename="../decodermpcfactory.cpp" line="59"/>
         <source>Musepack Plugin</source>
         <translation>Musepack Module</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="49"/>
+        <location filename="../decodermpcfactory.cpp" line="61"/>
         <source>Musepack Files</source>
         <translation>Musepack Bestanden</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="109"/>
+        <location filename="../decodermpcfactory.cpp" line="121"/>
         <source>About Musepack Audio Plugin</source>
         <translation>Over de Musepack Audio Module</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="110"/>
+        <location filename="../decodermpcfactory.cpp" line="122"/>
         <source>Qmmp Musepack Audio Plugin</source>
         <translation>Musepack Audio Module voor Qmmp</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="111"/>
+        <location filename="../decodermpcfactory.cpp" line="123"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -44,7 +44,7 @@
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="47"/>
         <source>Hz</source>
-        <translation>Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="48"/>
@@ -59,7 +59,7 @@
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="49"/>
         <source>kbps</source>
-        <translation>kbps</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="50"/>
@@ -69,7 +69,7 @@
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="50"/>
         <source>KB</source>
-        <translation>KB</translation>
+        <translation></translation>
     </message>
 </context>
 </TS>
