@@ -4,27 +4,27 @@
 <context>
     <name>DecoderMPCFactory</name>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="47"/>
+        <location filename="../decodermpcfactory.cpp" line="59"/>
         <source>Musepack Plugin</source>
         <translation>Musepack 插件</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="49"/>
+        <location filename="../decodermpcfactory.cpp" line="61"/>
         <source>Musepack Files</source>
         <translation>Musepack 文件</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="109"/>
+        <location filename="../decodermpcfactory.cpp" line="121"/>
         <source>About Musepack Audio Plugin</source>
         <translation>关于 Musepack 音频插件</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="110"/>
+        <location filename="../decodermpcfactory.cpp" line="122"/>
         <source>Qmmp Musepack Audio Plugin</source>
         <translation>Qmmp Musepack 音频插件</translation>
     </message>
     <message>
-        <location filename="../decodermpcfactory.cpp" line="111"/>
+        <location filename="../decodermpcfactory.cpp" line="123"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -34,42 +34,42 @@
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="46"/>
         <source>Length</source>
-        <translation type="unfinished"></translation>
+        <translation>长度</translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="47"/>
         <source>Sample rate</source>
-        <translation type="unfinished"></translation>
+        <translation>取样率</translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="47"/>
         <source>Hz</source>
-        <translation type="unfinished">Hz</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="48"/>
         <source>Channels</source>
-        <translation type="unfinished"></translation>
+        <translation>声音通道</translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="49"/>
         <source>Bitrate</source>
-        <translation type="unfinished"></translation>
+        <translation>比特率</translation>
     </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="49"/>
         <source>kbps</source>
-        <translation type="unfinished">kbps</translation>
-    </message>
-    <message>
-        <location filename="../mpcmetadatamodel.cpp" line="50"/>
-        <source>File size</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mpcmetadatamodel.cpp" line="50"/>
+        <source>File size</source>
+        <translation>文件大小</translation>
+    </message>
     <message>
         <location filename="../mpcmetadatamodel.cpp" line="50"/>
         <source>KB</source>
-        <translation type="unfinished">KB</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
