@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2009 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef DECODER_AUDIOFILE_H
@@ -30,36 +30,25 @@ extern "C"{
 class DecoderSndFile : public Decoder
 {
 public:
-    DecoderSndFile(QObject *, DecoderFactory *, Output *, const QString &);
+    DecoderSndFile(const QString &path);
     virtual ~DecoderSndFile();
 
     // Standard Decoder API
     bool initialize();
     qint64 totalTime();
-    void seek(qint64);
-    void stop();
-
+    int bitrate();
+    qint64 read(char *audio, qint64 maxSize);
+    void seek(qint64 time);
 
 private:
-    // thread run function
-    void run();
+
     // helper functions
-    void flush(bool = FALSE);
     void deinit();
 
-    // output buffer
-    char *m_output_buf;
-
     SNDFILE *m_sndfile;
-    ulong m_output_bytes, m_output_at;
-    //struct sndfile_data *m_data;
-    short *m_buf;
-    unsigned int bks;
-    bool m_done, m_finish, m_inited, m_user_stop;
-    long m_freq, m_bitrate;
-    int m_chan;
-    qint64 m_output_size;
-    qint64 m_totalTime, m_seekTime;
+    int m_bitrate;
+    quint32 m_freq;
+    qint64 m_totalTime;
     QString m_path;
 };
 
