@@ -4,33 +4,33 @@
 <context>
     <name>DecoderSndFileFactory</name>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="66"/>
+        <location filename="../decodersndfilefactory.cpp" line="63"/>
         <source>Sndfile Plugin</source>
         <translation>Sndfile プラグイン</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="68"/>
+        <location filename="../decodersndfilefactory.cpp" line="66"/>
         <source>PCM Files</source>
         <translation>PCM ファイル</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="132"/>
+        <location filename="../decodersndfilefactory.cpp" line="130"/>
         <source>About Sndfile Audio Plugin</source>
         <translation>Sndfile 音響プラグインについて</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="133"/>
+        <location filename="../decodersndfilefactory.cpp" line="131"/>
         <source>Qmmp Sndfile Audio Plugin</source>
         <translation>QMMP Sndfile 音響プラグイン</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="134"/>
+        <location filename="../decodersndfilefactory.cpp" line="132"/>
         <source>Compiled against</source>
         <translation>コンパイルに使用したライブラリ</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="135"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../decodersndfilefactory.cpp" line="133"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
