@@ -4,33 +4,33 @@
 <context>
     <name>DecoderSndFileFactory</name>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="66"/>
+        <location filename="../decodersndfilefactory.cpp" line="63"/>
         <source>Sndfile Plugin</source>
         <translation>Модуль Sndfile</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="68"/>
+        <location filename="../decodersndfilefactory.cpp" line="66"/>
         <source>PCM Files</source>
         <translation>Файли PCM</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="132"/>
+        <location filename="../decodersndfilefactory.cpp" line="130"/>
         <source>About Sndfile Audio Plugin</source>
         <translation>Про аудіо-модуль Sndfile</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="133"/>
+        <location filename="../decodersndfilefactory.cpp" line="131"/>
         <source>Qmmp Sndfile Audio Plugin</source>
         <translation>Модуль SndFile для Qmmp</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="134"/>
+        <location filename="../decodersndfilefactory.cpp" line="132"/>
         <source>Compiled against</source>
         <translation>Зкомпільовано з</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="135"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../decodersndfilefactory.cpp" line="133"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
