@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <taglib/tag.h>
@@ -43,7 +43,7 @@ VorbisMetaDataModel::~VorbisMetaDataModel()
 QHash<QString, QString> VorbisMetaDataModel::audioProperties()
 {
     QHash<QString, QString> ap;
-    TagLib::Ogg::Vorbis::File f (m_path.toLocal8Bit());
+    TagLib::Ogg::Vorbis::File f (m_path.toLocal8Bit().constData());
     if(f.audioProperties())
     {
         QString text = QString("%1").arg(f.audioProperties()->length()/60);
@@ -208,6 +208,6 @@ void VorbisCommentModel::save()
     //taglib bug workarround
     QString path = QString::fromLocal8Bit(m_file->name());
     delete m_file;
-    m_file = new TagLib::Ogg::Vorbis::File(path.toLocal8Bit());
+    m_file = new TagLib::Ogg::Vorbis::File(path.toLocal8Bit().constData());
     m_tag = m_file->tag();
 }
