@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -33,9 +33,10 @@ bool DecoderWavPackFactory::supports(const QString &source) const
     return (source.right(3).toLower() == ".wv");
 }
 
-bool DecoderWavPackFactory::canDecode(QIODevice *) const
+bool DecoderWavPackFactory::canDecode(QIODevice *input) const
 {
-    return false;
+    char buf[4];
+    return (input->peek(buf, 4) == 4 && !memcmp(buf, "wvpk", 4));
 }
 
 const DecoderProperties DecoderWavPackFactory::properties() const
@@ -67,11 +68,9 @@ QList<FileInfo *> DecoderWavPackFactory::createPlayList(const QString &fileName,
     //extract metadata of one cue track
     if(fileName.contains("://"))
     {
-        QString path = QUrl(fileName).path();
-        path.replace(QString(QUrl::toPercentEncoding("#")), "#");
-        path.replace(QString(QUrl::toPercentEncoding("?")), "?");
-        path.replace(QString(QUrl::toPercentEncoding("%")), "%");
-        path.replace(QString(QUrl::toPercentEncoding(":")), ":");
+        QString path = fileName;
+        path.remove("wvpack://");
+        path.remove(QRegExp("#\\d+$"));
         int track = fileName.section("#", -1).toInt();
         list = createPlayList(path, true);
         if (list.isEmpty() || track <= 0 || track > list.count())
@@ -85,7 +84,8 @@ QList<FileInfo *> DecoderWavPackFactory::createPlayList(const QString &fileName,
         return QList<FileInfo *>() << info;
     }
 
-    WavpackContext *ctx = WavpackOpenFileInput (fileName.toLocal8Bit(), err, OPEN_WVC | OPEN_TAGS, 0);
+    WavpackContext *ctx = WavpackOpenFileInput (fileName.toLocal8Bit().constData(),
+                                                err, OPEN_WVC | OPEN_TAGS, 0);
     if (!ctx)
     {
         qWarning("DecoderWavPackFactory: error: %s", err);
