@@ -4,7 +4,7 @@
 <context>
     <name>DecoderWavPackFactory</name>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="44"/>
+        <location filename="../decoderwavpackfactory.cpp" line="45"/>
         <source>WavPack Plugin</source>
         <translation>WavPack 插件</translation>
     </message>
@@ -29,7 +29,7 @@
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="46"/>
+        <location filename="../decoderwavpackfactory.cpp" line="47"/>
         <source>WavPack Files</source>
         <translation>WavPack 文件</translation>
     </message>
@@ -37,54 +37,54 @@
 <context>
     <name>WavPackMetaDataModel</name>
     <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
+        <location filename="../wavpackmetadatamodel.cpp" line="65"/>
         <source>Length</source>
-        <translation type="unfinished"></translation>
+        <translation>长度</translation>
     </message>
     <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
+        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
         <source>Sample rate</source>
+        <translation>取样率</translation>
+    </message>
+    <message>
+        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
+        <source>Hz</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
+        <source>Channels</source>
+        <translation>声音通道</translation>
+    </message>
     <message>
         <location filename="../wavpackmetadatamodel.cpp" line="68"/>
-        <source>Hz</source>
-        <translation type="unfinished">Hz</translation>
-    </message>
-    <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="69"/>
-        <source>Channels</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
         <source>Bitrate</source>
+        <translation>比特率</translation>
+    </message>
+    <message>
+        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
+        <source>kbps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../wavpackmetadatamodel.cpp" line="70"/>
-        <source>kbps</source>
-        <translation type="unfinished">kbps</translation>
-    </message>
-    <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
         <source>File size</source>
+        <translation>文件大小</translation>
+    </message>
+    <message>
+        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
+        <source>KB</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
+        <source>Ratio</source>
+        <translation>比值</translation>
+    </message>
     <message>
         <location filename="../wavpackmetadatamodel.cpp" line="72"/>
-        <source>KB</source>
-        <translation type="unfinished">KB</translation>
-    </message>
-    <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
-        <source>Ratio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="74"/>
         <source>Version</source>
-        <translation type="unfinished"></translation>
+        <translation>版本</translation>
     </message>
 </context>
 </TS>
