@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QMap>
@@ -26,18 +26,16 @@ WavPackMetaDataModel::WavPackMetaDataModel(const QString &path, QObject *parent)
 {
     if(path.contains("://"))
     {
-        QString p = QUrl(path).path();
-        p.replace(QString(QUrl::toPercentEncoding("#")), "#");
-        p.replace(QString(QUrl::toPercentEncoding("?")), "?");
-        p.replace(QString(QUrl::toPercentEncoding("%")), "%");
-        p.replace(QString(QUrl::toPercentEncoding(":")), ":");
+        QString p = path;
+        p.remove("wvpack://");
+        p.remove(QRegExp("#\\d+$"));
         m_path = p;
     }
     else
         m_path = path;
 
     char err[80];
-    m_ctx = WavpackOpenFileInput (m_path.toLocal8Bit(), err,
+    m_ctx = WavpackOpenFileInput (m_path.toLocal8Bit().constData(), err,
                                   OPEN_WVC | OPEN_EDIT_TAGS, 0);
     if (!m_ctx)
     {
