@@ -106,7 +106,7 @@ void DecoderWildMidiFactory::showAbout(QWidget *parent)
 QTranslator *DecoderWildMidiFactory::createTranslator(QObject *parent)
 {
     QTranslator *translator = new QTranslator(parent);
-    QString locale = QLocale::system().name();
+    QString locale = Qmmp::systemLanguageID();
     translator->load(QString(":/wildmidi_plugin_") + locale);
     return translator;
 }
