@@ -279,8 +279,9 @@ getDriver(int deviceID)
 #endif
   jack_driver_t *drv = &outDev[deviceID];
 
-  if(pthread_mutex_lock(&drv->mutex) != 0)
-    ERR("lock returned an error\n");
+  int err = 0;
+  if((err = pthread_mutex_lock(&drv->mutex)) != 0)
+    ERR("lock returned an error: %d\n", err);
 
   /* should we try to restart the jack server? */
   if(drv->jackd_died && drv->client == 0)
@@ -346,8 +347,9 @@ releaseDriver(jack_driver_t * drv)
      TRACE("deviceID == %d\n", drv->deviceID);
      #endif
    */
-  if(pthread_mutex_unlock(&drv->mutex) != 0)
-    ERR("lock returned an error\n");
+  int err = 0;
+  if((err = pthread_mutex_unlock(&drv->mutex)) != 0)
+    ERR("lock returned an error: %d\n", err);
 }
 
 
@@ -2258,7 +2260,9 @@ JACK_GetPositionFromDriver(jack_driver_t * drv, enum pos_enum position,
   long elapsedMS;
   double sec2msFactor = 1000;
 
+#if TRACE_ENABLE
   char *type_str = "UNKNOWN type";
+#endif
 
   /* if we are reset we should return a position of 0 */
   if(drv->state == RESET)
@@ -2269,15 +2273,21 @@ JACK_GetPositionFromDriver(jack_driver_t * drv, enum pos_enum position,
 
   if(type == WRITTEN)
   {
+#if TRACE_ENABLE
     type_str = "WRITTEN";
+#endif
     return_val = drv->client_bytes;
   } else if(type == WRITTEN_TO_JACK)
   {
+#if TRACE_ENABLE
     type_str = "WRITTEN_TO_JACK";
+#endif
     return_val = drv->written_client_bytes;
   } else if(type == PLAYED)       /* account for the elapsed time for the played_bytes */
   {
+#if TRACE_ENABLE
     type_str = "PLAYED";
+#endif
     return_val = drv->played_client_bytes;
     gettimeofday(&now, 0);
 
@@ -2316,9 +2326,10 @@ JACK_GetPositionFromDriver(jack_driver_t * drv, enum pos_enum position,
       return_val = 0;
     }
   }
-
+#if TRACE_ENABLE
   TRACE("drv->deviceID(%d), type(%s), return_val = %ld\n", drv->deviceID,
         type_str, return_val);
+#endif
 
   return return_val;
 }
@@ -2534,7 +2545,6 @@ JACK_Init(void)
 
     JACK_CleanupDriver(drv);
     JACK_ResetFromDriver(drv);
-    releaseDriver(drv);
   }
 
   client_name = 0;              /* initialize the name to null */
