@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 by Ilya Kotov                                      *
+ *   Copyright (C) 2009-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,14 +15,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-
 #include <QObject>
-#include <QApplication>
-#include <QtGlobal>
-
+#include <unistd.h>
 #include <stdio.h>
 #include <string.h>
 #include <iostream>
@@ -31,59 +28,49 @@
 #include <qmmp/visual.h>
 #include "outputwaveout.h"
 
-#define MAX_WAVEBLOCKS    32
+#define MAX_WAVEBLOCKS    256
 
 static CRITICAL_SECTION  cs;
 static HWAVEOUT          dev                    = NULL;
-static int               ScheduledBlocks        = 0;
+static unsigned int      ScheduledBlocks        = 0;
 static int               PlayedWaveHeadersCount = 0;          // free index
 static WAVEHDR*          PlayedWaveHeaders [MAX_WAVEBLOCKS];
 
 
 
-static void CALLBACK wave_callback (HWAVE hWave, UINT uMsg, DWORD dwInstance, DWORD dwParam1, DWORD dwParam2 )
+static void CALLBACK wave_callback (HWAVE hWave, UINT uMsg, DWORD dwInstance, DWORD dwParam1, DWORD dwParam2)
 {
-    if ( uMsg == WOM_DONE )
+    if (uMsg == WOM_DONE)
     {
         EnterCriticalSection (&cs);
         PlayedWaveHeaders [PlayedWaveHeadersCount++] = (WAVEHDR*) dwParam1;
+        ScheduledBlocks--;                        // decrease the number of USED blocks
         LeaveCriticalSection (&cs);
     }
 }
 
 static void
-free_memory ( void )
+free_memory (void)
 {
     WAVEHDR*  wh;
     HGLOBAL   hg;
 
-    EnterCriticalSection ( &cs );
+    EnterCriticalSection (&cs);
     wh = PlayedWaveHeaders [--PlayedWaveHeadersCount];
-    ScheduledBlocks--;                        // decrease the number of USED blocks
-    LeaveCriticalSection ( &cs );
+    LeaveCriticalSection (&cs);
 
-    waveOutUnprepareHeader ( dev, wh, sizeof (WAVEHDR) );
+    waveOutUnprepareHeader (dev, wh, sizeof (WAVEHDR));
 
-    hg = GlobalHandle ( wh -> lpData );       // Deallocate the buffer memory
+    hg = GlobalHandle (wh -> lpData);       // Deallocate the buffer memory
     GlobalUnlock (hg);
     GlobalFree   (hg);
 
-    hg = GlobalHandle ( wh );                 // Deallocate the header memory
+    hg = GlobalHandle (wh);                 // Deallocate the header memory
     GlobalUnlock (hg);
     GlobalFree   (hg);
 }
 
-static int
-Box ( const char* msg )
-{
-    //MessageBox ( NULL, ms"Error Message . . .", MB_OK | MB_ICONEXCLAMATION );
-    return -1;
-}
-
-
-
-OutputWaveOut::OutputWaveOut(QObject * parent)
-        : Output(parent)
+OutputWaveOut::OutputWaveOut() : Output()
 {
     //m_connection = 0;
     //m_dev = 0;
@@ -94,8 +81,13 @@ OutputWaveOut::~OutputWaveOut()
     uninitialize();
 }
 
-void OutputWaveOut::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
+bool OutputWaveOut::initialize(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
+    if (!waveOutGetNumDevs ())
+    {
+        qWarning("OutputWaveOut: no audio device found");
+        return false;
+    }
     WAVEFORMATEX fmt;
     UINT deviceID = WAVE_MAPPER;
 
@@ -109,36 +101,33 @@ void OutputWaveOut::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
     switch (waveOutOpen (&dev, deviceID, &fmt, (DWORD)wave_callback, 0, CALLBACK_FUNCTION))
     {
     case MMSYSERR_ALLOCATED:
-        return qWarning("OutputWaveOut: Device is already open.");
+        qWarning("OutputWaveOut: Device is already open.");
+        return false;
     case MMSYSERR_BADDEVICEID:
-        return qWarning("OutputWaveOut: The specified device is out of range.");
+        qWarning("OutputWaveOut: The specified device is out of range.");
+        return false;
     case MMSYSERR_NODRIVER:
-        return qWarning("OutputWaveOut: There is no audio driver in this system.");
+        qWarning("OutputWaveOut: There is no audio driver in this system.");
+        return false;
     case MMSYSERR_NOMEM:
-        return qWarning("OutputWaveOut: Unable to allocate sound memory.");
+        qWarning("OutputWaveOut: Unable to allocate sound memory.");
+        return false;
     case WAVERR_BADFORMAT:
-        return qWarning("OutputWaveOut: This audio format is not supported.");
+        qWarning("OutputWaveOut: This audio format is not supported.");
+        return false;
     case WAVERR_SYNC:
-        return qWarning("OutputWaveOut: The device is synchronous.");
+        qWarning("OutputWaveOut: The device is synchronous.");
+        return false;
     default:
-        return qWarning("OutputWaveOut: Unknown media error.");
+        qWarning("OutputWaveOut: Unknown media error.");
+        return false;
     case MMSYSERR_NOERROR:
         break;
     }
 
     waveOutReset (dev);
-    InitializeCriticalSection ( &cs );
-    Output::configure(freq, chan, format);
-    return;
-}
-
-bool OutputWaveOut::initialize()
-{
-    if (!waveOutGetNumDevs ())
-    {
-        qWarning("OutputWaveOut: no audio device found");
-        return false;
-    }
+    InitializeCriticalSection (&cs);
+    configure(freq, chan, Qmmp::PCM_S16LE);
 
     return true;
 }
@@ -157,70 +146,125 @@ qint64 OutputWaveOut::writeAudio(unsigned char *data, qint64 len)
     void*      allocptr;
     len = qMin(len, (qint64)1024);
 
-    do
+
+    while (PlayedWaveHeadersCount > 0)                        // free used blocks ...
+        free_memory ();
+
+    if (ScheduledBlocks >= sizeof(PlayedWaveHeaders)/sizeof(*PlayedWaveHeaders)) // wait for a free block ...
     {
-        while ( PlayedWaveHeadersCount > 0 )                        // free used blocks ...
-            free_memory ();
-
-        if ( ScheduledBlocks < sizeof(PlayedWaveHeaders)/sizeof(*PlayedWaveHeaders) ) // wait for a free block ...
-            break;
-        usleep (500);
-
+        usleep(50000);
+        return 0;
     }
-    while (1);
 
-    if ( (hg2 = GlobalAlloc ( GMEM_MOVEABLE, len )) == NULL )   // allocate some memory for a copy of the buffer
-        return Box ( "GlobalAlloc failed." );
+    if ((hg2 = GlobalAlloc (GMEM_MOVEABLE, len)) == NULL)   // allocate some memory for a copy of the buffer
+    {
+        qWarning("OutputWaveOut: GlobalAlloc failed");
+        return 0;
+    }
 
     allocptr = GlobalLock (hg2);
-    CopyMemory ( allocptr, data, len );                         // Here we can call any modification output functions we want....
+    CopyMemory (allocptr, data, len);                         // Here we can call any modification output functions we want....
 
-    if ( (hg = GlobalAlloc (GMEM_MOVEABLE | GMEM_ZEROINIT, sizeof (WAVEHDR))) == NULL ) // now make a header and WRITE IT!
+    if ((hg = GlobalAlloc (GMEM_MOVEABLE | GMEM_ZEROINIT, sizeof (WAVEHDR))) == NULL) // now make a header and WRITE IT!
         return -1;
 
     wh                   = (wavehdr_tag*)GlobalLock (hg);
     wh->dwBufferLength   = len;
     wh->lpData           = (CHAR *)allocptr;
 
-    if ( waveOutPrepareHeader ( dev, wh, sizeof (WAVEHDR)) != MMSYSERR_NOERROR )
+    if (waveOutPrepareHeader (dev, wh, sizeof (WAVEHDR)) != MMSYSERR_NOERROR)
     {
         GlobalUnlock (hg);
         GlobalFree   (hg);
         return -1;
     }
 
-    if ( waveOutWrite ( dev, wh, sizeof (WAVEHDR)) != MMSYSERR_NOERROR )
+    if (waveOutWrite (dev, wh, sizeof (WAVEHDR)) != MMSYSERR_NOERROR)
     {
         GlobalUnlock (hg);
         GlobalFree   (hg);
         return -1;
     }
 
-    EnterCriticalSection ( &cs );
+    EnterCriticalSection (&cs);
     ScheduledBlocks++;
-    LeaveCriticalSection ( &cs );
+    LeaveCriticalSection (&cs);
 
     return len;
 }
 
+void OutputWaveOut::drain()
+{
+    while (ScheduledBlocks > 0)
+        Sleep(10);
+    while (PlayedWaveHeadersCount > 0)                        // free used blocks ...
+        free_memory();
+}
+
+void OutputWaveOut::suspend()
+{
+    waveOutPause(dev);
+}
+
+void OutputWaveOut::resume()
+{
+    waveOutRestart(dev);
+}
+
+void OutputWaveOut::reset()
+{
+   while (PlayedWaveHeadersCount > 0)                        // free used blocks ...
+      free_memory ();
+   waveOutReset (dev);
+}
+
 void OutputWaveOut::uninitialize()
 {
     if (dev)
     {
-        while ( ScheduledBlocks > 0 )
-        {
-            Sleep (ScheduledBlocks);
-            while ( PlayedWaveHeadersCount > 0 )                        // free used blocks ...
-                free_memory ();
-        }
+        waveOutReset(dev); // reset the device
+        while (ScheduledBlocks > 0);
+            Sleep (10);
+
+        while (PlayedWaveHeadersCount > 0)         // free used blocks ...
+            free_memory ();
 
         waveOutReset (dev);      // reset the device
         waveOutClose (dev);      // close the device
         dev = 0;
     }
 
-    DeleteCriticalSection ( &cs );
-    ScheduledBlocks = 0;
+    DeleteCriticalSection (&cs);
     return;
 }
 
+/***** MIXER *****/
+VolumeWaveOut::VolumeWaveOut()
+{}
+
+VolumeWaveOut::~VolumeWaveOut()
+{}
+
+void VolumeWaveOut::setVolume(const VolumeSettings &vol)
+{
+    DWORD data = (vol.right*0xFFFF/100 << 16) | vol.left*0xFFFF/100;
+    waveOutSetVolume(0, data);
+}
+
+VolumeSettings VolumeWaveOut::volume() const
+{
+    VolumeSettings vol;
+    DWORD data;
+    waveOutGetVolume(0, (PDWORD)&data);
+    vol.left = (long)LOWORD(data) * 100 / 0xFFFF + 1;
+    vol.right = (long)HIWORD(data) * 100 / 0xFFFF + 1;
+    return vol;
+}
+
+bool VolumeWaveOut::isSupported() const
+{
+    WAVEOUTCAPS waveCaps;
+    if(waveOutGetDevCaps(0,(LPWAVEOUTCAPS)&waveCaps, sizeof(WAVEOUTCAPS)) != MMSYSERR_NOERROR)
+        return false;
+    return (waveCaps.dwSupport & WAVECAPS_VOLUME) != 0;
+}
