@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,9 +21,9 @@
 #ifndef OUTPUTWAVEOUT_H
 #define OUTPUTWAVEOUT_H
 
-#include <QObject>
 #include <stdio.h>
 #include <windows.h>
+#include <qmmp/volume.h>
 #include <qmmp/output.h>
 
 /**
@@ -31,26 +31,37 @@
 */
 class OutputWaveOut : public Output
 {
-    Q_OBJECT
 public:
-    OutputWaveOut(QObject * parent = 0);
+    OutputWaveOut();
     ~OutputWaveOut();
 
     bool initialize(quint32, int,  Qmmp::AudioFormat format);
-    qint64 latency();
 
-private:
     //output api
+    qint64 latency();
     qint64 writeAudio(unsigned char *data, qint64 size);
     void drain();
     void suspend();
     void resume();
-    void reset(); 
+    void reset();
 
+private:
     // helper functions
     void status();
     void uninitialize();
 };
 
+class VolumeWaveOut : public Volume
+{
+public:
+    VolumeWaveOut();
+    ~VolumeWaveOut();
+
+    void setVolume(const VolumeSettings &vol);
+    VolumeSettings volume() const;
+
+    bool isSupported() const;
+};
+
 
 #endif // OUTPUTWAVEOUT_H
