@@ -24,16 +24,17 @@
 #include <qmmp/qmmp.h>
 #include <qmmp/statehandler.h>
 #include <qmmp/inputsource.h>
+#include "mmsinputsource.h"
 #include "mmsstreamreader.h"
 
-MMSStreamReader::MMSStreamReader(const QString &url, QObject *parent)
-        : QIODevice(parent)
+MMSStreamReader::MMSStreamReader(const QString &url, MMSInputSource *parent) : QIODevice(parent)
 {
+    m_parent = parent;
     m_url = url;
     m_handle = 0;
     m_aborted = false;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    m_prebuf_size = settings.value("MMS/buffer_size",128).toInt() * 1024;
+    m_prebuf_size = settings.value("MMS/buffer_size",384).toInt() * 1024;
     m_buffer_size = m_prebuf_size;
     m_buffer = (char *)malloc(m_buffer_size);
     m_ready = false;
@@ -122,7 +123,8 @@ void MMSStreamReader::abort()
     }
     m_aborted = true;
     m_mutex.unlock();
-    m_thread->wait();
+    if(m_thread->isRunning())
+        m_thread->wait();
     m_ready = false;
     if (m_handle)
         mmsx_close(m_handle);
@@ -197,7 +199,7 @@ void MMSStreamReader::checkBuffer()
         qDebug("MMSStreamReader: ready");
         QMap<Qmmp::MetaData, QString> metaData;
         metaData.insert(Qmmp::URL, m_url);
-        (qobject_cast<InputSource *>(parent()))->addMetaData(metaData);
+        m_parent->addMetaData(metaData);
         emit ready();
     }
     else if (!m_ready)
