@@ -201,7 +201,6 @@ void PlayList::createActions()
                                 SLOT(removeDuplicates())));
     //sort menu
     m_sortMenu->addAction(SET_ACTION(ActionManager::PL_SHOW_INFO, m_pl_manager, SLOT (showDetails ())));
-    m_sortMenu->addAction (ActionManager::instance()->action(ActionManager::PL_SHOW_INFO));
     m_sortMenu->addSeparator();
 
     QMenu* sort_mode_menu = new QMenu (tr("Sort List"), m_sortMenu);
@@ -492,7 +491,7 @@ void PlayList::showSortMenu()
 
 QString PlayList::formatTime (int sec)
 {
-    if(sec > 3600)
+    if(sec >= 3600)
         sec /= 60;
     return QString("%1:%2").arg(sec/60, 2, 10, QChar('0')).arg(sec%60, 2, 10, QChar('0'));
 }
