@@ -35,22 +35,28 @@
 #define VISUAL_NODE_SIZE 512 //samples
 #define VISUAL_BUFFER_SIZE (5*VISUAL_NODE_SIZE)
 
-Analyzer::Analyzer (QWidget *parent)
-        : Visual (parent), m_fps (20)
+Analyzer::Analyzer (QWidget *parent) : Visual (parent), m_fps (20)
 {
+    m_intern_vis_data = 0;
+    m_peaks = 0;
+    m_x_scale = 0;
+    m_buffer_at = 0;
+    m_rows = 0;
+    m_cols = 0;
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     restoreGeometry(settings.value("Analyzer/geometry").toByteArray());
-    setFixedSize(2*300-30,105);
+    //setAttribute(Qt::WA_TranslucentBackground);
+    setMinimumSize(2*300-30,105);
     m_timer = new QTimer (this);
     connect(m_timer, SIGNAL (timeout()), this, SLOT (timeout()));
     m_left_buffer = new short[VISUAL_BUFFER_SIZE];
     m_right_buffer = new short[VISUAL_BUFFER_SIZE];
-    m_buffer_at = 0;
+
     clear();
     setWindowTitle (tr("Qmmp Analyzer"));
 
     double peaks_speed[] = { 0.05, 0.1, 0.2, 0.4, 0.8 };
-    double analyzer_speed[] = { 1.2, 1.8, 2.2, 2.8, 2.4 };
+    double analyzer_speed[] = { 1.2, 1.8, 2.2, 2.4, 2.8 };
     int intervals[] = { 20 , 40 , 100 , 200 };
 
     m_peaks_falloff =
@@ -63,23 +69,34 @@ Analyzer::Analyzer (QWidget *parent)
     m_color2.setNamedColor(settings.value("Analyzer/color2", "Yellow").toString());
     m_color3.setNamedColor(settings.value("Analyzer/color3", "Red").toString());
     m_bgColor.setNamedColor(settings.value("Analyzer/bg_color", "Black").toString());
+    //m_bgColor.setAlpha(0);
     m_peakColor.setNamedColor(settings.value("Analyzer/peak_color", "Cyan").toString());
+    m_cell_size = settings.value("Analyzer/cells_size", QSize(15, 6)).toSize();
+
+    QAction *fullScreenAction = new QAction(this);
+    fullScreenAction->setShortcut(tr("F"));
+    connect(fullScreenAction, SIGNAL(triggered()), SLOT(toggleFullScreen()));
+    addAction(fullScreenAction);
 }
 
 Analyzer::~Analyzer()
 {
     delete [] m_left_buffer;
     delete [] m_right_buffer;
+
+    if(m_peaks)
+        delete [] m_peaks;
+    if(m_intern_vis_data)
+        delete [] m_intern_vis_data;
+    if(m_x_scale)
+        delete [] m_x_scale;
 }
 
 void Analyzer::clear()
 {
     m_buffer_at = 0;
-    for (int i = 0; i< 75; ++i)
-    {
-        m_intern_vis_data[i] = 0;
-        m_peaks[i] = 0;
-    }
+    m_rows = 0;
+    m_cols = 0;
     update();
 }
 
@@ -160,69 +177,86 @@ void Analyzer::process (short *left, short *right)
     if (!state)
         state = fft_init();
 
+    int rows = (height() - 2) / m_cell_size.height();
+    int cols = (width() - 2) / m_cell_size.width() / 2;
+
+    if(m_rows != rows || m_cols != cols)
+    {
+        m_rows = rows;
+        m_cols = cols;
+        if(m_peaks)
+            delete [] m_peaks;
+        if(m_intern_vis_data)
+            delete [] m_intern_vis_data;
+        if(m_x_scale)
+            delete [] m_x_scale;
+        m_peaks = new double[m_cols * 2];
+        m_intern_vis_data = new double[m_cols * 2];
+        m_x_scale = new int[m_cols + 1];
+
+        for(int i = 0; i < m_cols * 2; ++i)
+        {
+            m_peaks[i] = 0;
+            m_intern_vis_data[i] = 0;
+        }
+        for(int i = 0; i < m_cols + 1; ++i)
+            m_x_scale[i] = pow(pow(255.0, 1.0 / m_cols), i);
+    }
+
     short dest_l[256];
     short dest_r[256];
-
-    const int xscale_short[] =
-        {
-            0, 1, 2, 3, 4, 5, 6, 7, 8, 11, 15, 20, 27,
-            36, 47, 62, 82, 107, 141, 184, 255
-        };
+    short yl, yr;
+    int j, k, magnitude_l, magnitude_r;
 
     calc_freq (dest_l, left);
     calc_freq (dest_r, right);
 
-    const double y_scale = 3.60673760222;   /* 20.0 / log(256) */
-    int yl,yr, j;
+    double y_scale = (double) 1.25 * m_rows / log(256);
 
-    for (int i = 0; i < 19; i++)
+    for (int i = 0; i < m_cols; i++)
     {
+        j = m_cols * 2 - i - 1; //mirror index
         yl = yr = 0;
+        magnitude_l = magnitude_r = 0;
 
-        for (j = xscale_short[i];  j < xscale_short[i + 1]; j++)
+        if(m_x_scale[i] == m_x_scale[i + 1])
         {
-            if (dest_l[j] > yl)
-                yl = dest_l[j];
-            if (dest_r[j] > yr)
-                yr = dest_r[j];
+            yl = dest_l[i];
+            yr = dest_r[i];
         }
-        yl >>= 7;
+        for (k = m_x_scale[i]; k < m_x_scale[i + 1]; k++)
+        {
+            yl = qMax(dest_l[k], yl);
+            yr = qMax(dest_r[k], yr);
+        }
+
+        yl >>= 7; //256
         yr >>= 7;
-        int magnitude_l = 0;
-        int magnitude_r = 0;
 
         if (yl)
         {
             magnitude_l = int(log (yl) * y_scale);
-            if (magnitude_l > 15)
-                magnitude_l = 15;
-            if (magnitude_l < 0)
-                magnitude_l = 0;
+            magnitude_l = qBound(0, magnitude_l, m_rows);
         }
         if (yr)
         {
             magnitude_r = int(log (yr) * y_scale);
-            if (magnitude_r > 15)
-                magnitude_r = 15;
-            if (magnitude_r < 0)
-                magnitude_r = 0;
+            magnitude_r = qBound(0, magnitude_r, m_rows);
         }
 
-        m_intern_vis_data[i] -= m_analyzer_falloff;
-        m_intern_vis_data[i] = magnitude_l > m_intern_vis_data[i]
-                               ? magnitude_l : m_intern_vis_data[i];
+        m_intern_vis_data[i] -= m_analyzer_falloff * m_rows / 15;
+        m_intern_vis_data[i] = magnitude_l > m_intern_vis_data[i] ? magnitude_l : m_intern_vis_data[i];
 
-        m_intern_vis_data[37-i] -= m_analyzer_falloff;
-        m_intern_vis_data[37-i] = magnitude_r > m_intern_vis_data[37-i]
-                                  ? magnitude_r : m_intern_vis_data[37-i];
+        m_intern_vis_data[j] -= m_analyzer_falloff * m_rows / 15;
+        m_intern_vis_data[j] = magnitude_r > m_intern_vis_data[j] ? magnitude_r : m_intern_vis_data[j];
 
         if (m_show_peaks)
         {
-            m_peaks[i] -= m_peaks_falloff;
+            m_peaks[i] -= m_peaks_falloff * m_rows / 15;
             m_peaks[i] = magnitude_l > m_peaks[i] ? magnitude_l : m_peaks[i];
 
-            m_peaks[37-i] -= m_peaks_falloff;
-            m_peaks[37-i] = magnitude_r > m_peaks[37-i] ? magnitude_r : m_peaks[37-i];
+            m_peaks[j] -= m_peaks_falloff * m_rows / 15;
+            m_peaks[j] = magnitude_r > m_peaks[j] ? magnitude_r : m_peaks[j];
         }
     }
 }
@@ -230,34 +264,37 @@ void Analyzer::process (short *left, short *right)
 void Analyzer::draw (QPainter *p)
 {
     QBrush brush(Qt::SolidPattern);
-    for (int j = 0; j < 19; ++j)
+    int x = 0;
+    int rdx = qMax(0, width() - 2 * m_cell_size.width() * m_cols);
+
+    for (int j = 0; j < m_cols * 2; ++j)
     {
+        x = j * m_cell_size.width() + 1;
+        if(j >= m_cols)
+            x += rdx; //correct right part position
+
         for (int i = 0; i <= m_intern_vis_data[j]; ++i)
         {
-            if (i <= 5)
+            if (i <= m_rows/3)
                 brush.setColor(m_color1);
-            else if (i > 5 && i <= 10)
+            else if (i > m_rows/3 && i <= 2 * m_rows / 3)
                 brush.setColor(m_color2);
             else
                 brush.setColor(m_color3);
-            p->fillRect (j*15+1, height() - i*7, 12, 4, brush);
-        }
 
-        for (int i = 0; i <= m_intern_vis_data[19+j]; ++i)
-        {
-            if (i <= 5)
-                brush.setColor(m_color1);
-            else if (i > 5 && i <= 10)
-                brush.setColor(m_color2);
-            else
-                brush.setColor(m_color3);
-            p->fillRect ((j+19)*15+1, height() - i*7, 12, 4, brush);
+            p->fillRect (x, height() - i * m_cell_size.height() + 1,
+                         m_cell_size.width() - 2, m_cell_size.height() - 2, brush);
         }
 
         if (m_show_peaks)
         {
-            p->fillRect (j*15+1, height() - int(m_peaks[j])*7, 12, 4, m_peakColor);
-            p->fillRect ((j+19)*15+1, height() - int(m_peaks[j+19])*7, 12, 4, m_peakColor);
+            p->fillRect (x, height() - int(m_peaks[j])*m_cell_size.height() + 1,
+                         m_cell_size.width() - 2, m_cell_size.height() - 2, m_peakColor);
         }
     }
 }
+
+void Analyzer::toggleFullScreen()
+{
+    setWindowState(windowState() ^Qt::WindowFullScreen);
+}
