@@ -4,120 +4,130 @@
 <context>
     <name>Analyzer</name>
     <message>
-        <location filename="../analyzer.cpp" line="51"/>
+        <location filename="../analyzer.cpp" line="56"/>
         <source>Qmmp Analyzer</source>
         <translation>Qmmp Analizator</translation>
     </message>
+    <message>
+        <location filename="../analyzer.cpp" line="77"/>
+        <source>F</source>
+        <translation>F</translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="13"/>
+        <location filename="../settingsdialog.ui" line="14"/>
         <source>Analyzer Plugin Settings</source>
         <translation>Ustawienia Wtyczki Analizator</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="25"/>
+        <location filename="../settingsdialog.ui" line="26"/>
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="34"/>
+        <location filename="../settingsdialog.ui" line="35"/>
         <source>Show peaks</source>
         <translation>Pokaż piki</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../settingsdialog.ui" line="42"/>
         <source>Analyzer falloff:</source>
         <translation>Analizator opadanie:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="55"/>
-        <location filename="../settingsdialog.ui" line="97"/>
+        <location filename="../settingsdialog.ui" line="56"/>
+        <location filename="../settingsdialog.ui" line="98"/>
         <source>Slowest</source>
         <translation>Najwolniej</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="60"/>
-        <location filename="../settingsdialog.ui" line="102"/>
+        <location filename="../settingsdialog.ui" line="61"/>
+        <location filename="../settingsdialog.ui" line="103"/>
         <source>Slow</source>
         <translation>Wolno</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="65"/>
-        <location filename="../settingsdialog.ui" line="107"/>
+        <location filename="../settingsdialog.ui" line="66"/>
+        <location filename="../settingsdialog.ui" line="108"/>
         <source>Medium</source>
         <translation>Średnio</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="70"/>
-        <location filename="../settingsdialog.ui" line="112"/>
+        <location filename="../settingsdialog.ui" line="71"/>
+        <location filename="../settingsdialog.ui" line="113"/>
         <source>Fast</source>
         <translation>Szybko</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="75"/>
-        <location filename="../settingsdialog.ui" line="117"/>
+        <location filename="../settingsdialog.ui" line="76"/>
+        <location filename="../settingsdialog.ui" line="118"/>
         <source>Fastest</source>
         <translation>Najszybciej</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="83"/>
+        <location filename="../settingsdialog.ui" line="84"/>
         <source>Peaks falloff:</source>
         <translation>Opadanie pików:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="125"/>
+        <location filename="../settingsdialog.ui" line="126"/>
         <source>Refresh rate:</source>
         <translation>Odświeżanie:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="139"/>
+        <location filename="../settingsdialog.ui" line="140"/>
         <source>50 FPS</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="144"/>
+        <location filename="../settingsdialog.ui" line="145"/>
         <source>25 FPS</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="149"/>
+        <location filename="../settingsdialog.ui" line="150"/>
         <source>10 FPS</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="154"/>
+        <location filename="../settingsdialog.ui" line="155"/>
         <source>5 FPS</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="171"/>
+        <location filename="../settingsdialog.ui" line="163"/>
+        <source>Cells size:</source>
+        <translation>Rozmiar komórki:</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="223"/>
         <source>Colors</source>
         <translation>Kolory</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="177"/>
+        <location filename="../settingsdialog.ui" line="229"/>
         <source>Peaks:</source>
         <translation>Piki:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="203"/>
+        <location filename="../settingsdialog.ui" line="261"/>
         <source>Analyzer #1:</source>
         <translation>Analizator #1:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="229"/>
+        <location filename="../settingsdialog.ui" line="293"/>
         <source>Background:</source>
         <translation>Tło:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="255"/>
+        <location filename="../settingsdialog.ui" line="325"/>
         <source>Analyzer #2:</source>
         <translation>Analizator #2:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="294"/>
+        <location filename="../settingsdialog.ui" line="370"/>
         <source>Analyzer #3:</source>
         <translation>Analizator #3:</translation>
     </message>
