@@ -44,6 +44,10 @@ public:
      * @param parent Parent object.
      */
     AbstractEngine(QObject *parent = 0);
+    /*!
+     * Destructor.
+     */
+    virtual ~AbstractEngine();
     /*!
      * Prepares decoder for usage.
      * Subclass should reimplement this function.
