@@ -114,7 +114,7 @@ void Decoder::checkFactories()
             QPluginLoader loader(pluginsDir.absoluteFilePath(fileName));
             QObject *plugin = loader.instance();
             if (loader.isLoaded())
-                qDebug("Decoder: plugin loaded - %s", qPrintable(fileName));
+                qDebug("Decoder: loaded plugin %s", qPrintable(fileName));
             else
                 qWarning("Decoder: %s", qPrintable(loader.errorString ()));
             DecoderFactory *factory = 0;
@@ -185,7 +185,10 @@ DecoderFactory *Decoder::findByPath(const QString& source, bool useContent)
         //try last factory with stream based input or local files support
         if (fact && isEnabled(fact) && (!fact->properties().noInput ||
                                         fact->properties().protocols.contains("file")))
-            return fact;
+        {
+            if(fact->canDecode(&buffer))
+                return fact;
+        }
 
         foreach(DecoderFactory *fact, *m_factories)
         {
