@@ -92,15 +92,32 @@ public:
      */
     QIODevice *input();
     /*!
-     * Returns DecoderFactory pointer which supports file \b path or 0 if file \b path is unsupported
+     * Informs decoder about new received metadata.
+     * Call of this function is required for all non-local streams/files
+     * @param metaData Metadata map.
      */
-    static DecoderFactory *findByPath(const QString &path);
+    void addMetaData(const QMap<Qmmp::MetaData, QString> &metaData);
+    /*!
+     * Returns \b true when new metadata has received, otherwise returns \b false.
+     */
+    bool hasMetaData() const;
+    /*!
+     * Takes metadata out of decoder and returns it.
+     * Attention: hasMetaData() should return \b true before use of this fuction.
+     */
+    QMap<Qmmp::MetaData, QString> takeMetaData();
+    /*!
+     * Returns DecoderFactory pointer which supports file \b path or 0 if file \b path is unsupported
+     * @param path Full local file path
+     * @param useContent Content-based file type determination (\b true - enabled, \b false - disabled)
+     */
+    static DecoderFactory *findByPath(const QString &path, bool useContent = false);
     /*!
      * Returns DecoderFactory pointer which supports mime type \b mime or \b 0 if mime type \b mime is unsupported
      */
     static DecoderFactory *findByMime(const QString &mime);
     /*!
-     * Returns DecoderFactory pointer which supports data provided by QIODevice \b input
+     * Returns DecoderFactory pointer which supports data provided by \b input
      * or \b 0 if data is unsupported.
      */
     static DecoderFactory *findByContent(QIODevice *input);
@@ -113,9 +130,10 @@ public:
      */
     static QList<DecoderFactory*> *factories();
     /*!
-     * Returns a list of input plugin file names.
+     * Returns plugin file path.
+     * @param factory Decoder plugin factory.
      */
-    static QStringList files();
+    static QString file(DecoderFactory *factory);
     /*!
      * Returns a list of supported protocols (including meta-protocols).
      * This fuction ignores disabled decoders.
@@ -147,9 +165,11 @@ private:
     static QList<DecoderFactory*> *m_factories;
     static QList<DecoderFactory*> *m_disabledFactories;
     static DecoderFactory *m_lastFactory;
-    static QStringList m_files;
+    static QHash <DecoderFactory*, QString> *m_files;
     AudioParameters m_parameters;
     QIODevice *m_input;
+    bool m_hasMetaData;
+    QMap<Qmmp::MetaData, QString> m_metaData;
     QMap <Qmmp::ReplayGainKey, double> m_rg; //replay gain information
 };
 
