@@ -58,6 +58,8 @@ void set_preamp(int chn, float val);
 
 
 int iir(void * d, int length, int nch);
+int iir32(void * d, int length, int nch);
+int iir24(void * d, int length, int nch);
 
 #ifdef ARCH_X86
 __inline__ int round_trick(float floatvalue_to_round);
@@ -71,7 +73,6 @@ __inline__ int round_ppc(float x);
 
 extern float preamp[EQ_CHANNELS];
 extern sIIRCoefficients *iir_cf;
-extern unsigned int rate;
 extern int band_count;
 
 #ifdef BENCHMARK
