@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef INPUTSOURCE_H
@@ -25,6 +25,9 @@
 #include <QString>
 #include <QStringList>
 #include <QIODevice>
+#include <QMap>
+#include <QHash>
+#include "qmmp.h"
 #include "inputsourcefactory.h"
 
 /*! @brief The InputSource class provides the base interface class of transports.
@@ -70,6 +73,36 @@ public:
      * Sets start position to \b offset ms.
      */
     void setOffset(qint64 offset);
+    /*!
+     * Informs input source object about new received metadata.
+     * Call of this function is required for all non-local streams/files
+     * @param metaData Metadata map.
+     */
+    void addMetaData(const QMap<Qmmp::MetaData, QString> &metaData);
+    /*!
+     * Returns \b true when new metadata has received, otherwise returns \b false.
+     */
+    bool hasMetaData() const;
+    /*!
+     * Takes metadata out of InputSource object and returns it.
+     * Attention: hasMetaData() should return \b true before use of this fuction.
+     */
+    QMap<Qmmp::MetaData, QString> takeMetaData();
+    /*!
+     * Informs input source object about received stream information (for example icy data).
+     * Call of this function is required for all non-local streams/files
+     * @param info Stream information map.
+     */
+    void addStreamInfo(const QHash<QString, QString> &info);
+    /*!
+     * Returns \b true when stream information has received, otherwise returns \b false.
+     */
+    bool hasStreamInfo() const;
+    /*!
+     * Takes stream information out of InputSource object and returns it.
+     * Attention: hasStreamInfo() should return \b true before use of this fuction.
+     */
+    QHash<QString, QString> takeStreamInfo();
     /*!
      * Creates InputSource object.
      * @param url Input source path or url.
@@ -82,9 +115,10 @@ public:
      */
     static QList<InputSourceFactory *> *factories();
     /*!
-     * Returns a list of transport plugin file names.
+     * Returns plugin file path.
+     * @param factory Transport plugin factory.
      */
-    static QStringList files();
+    static QString file(InputSourceFactory *factory);
     /*!
      * Returns a list of supported protocols.
      */
@@ -103,9 +137,12 @@ signals:
 private:
     QString m_url;
     qint64 m_offset;
+    QMap<Qmmp::MetaData, QString> m_metaData;
+    QHash<QString, QString> m_streamInfo;
+    bool m_hasMetaData, m_hasStreamInfo;
     static void checkFactories();
     static QList<InputSourceFactory*> *m_factories;
-    static QStringList m_files;
+    static QHash <InputSourceFactory*, QString> *m_files;
 };
 
 #endif // INPUTSOURCE_H
