@@ -381,8 +381,9 @@ void QmmpAudioEngine::run()
             else if(!m_decoders.isEmpty())
             {
                 m_inputs.take(m_decoder)->deleteLater ();
-                delete m_decoder;
+                Decoder *d = m_decoder;
                 m_decoder = m_decoders.dequeue();
+                delete d;
                 //m_seekTime = m_inputs.value(m_decoder)->offset();
                 m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
                 //use current output if possible
@@ -447,8 +448,9 @@ void QmmpAudioEngine::run()
     if(m_decoder)
     {
         m_inputs.take(m_decoder)->deleteLater ();
-        delete m_decoder;
+        Decoder *d = m_decoder;
         m_decoder = 0;
+        delete d;
     }
 
     mutex()->lock ();
@@ -531,7 +533,7 @@ void QmmpAudioEngine::sendMetaData()
 
 OutputWriter *QmmpAudioEngine::createOutput()
 {
-    OutputWriter *output = new OutputWriter(this);
+    OutputWriter *output = new OutputWriter(0);
     if (!output->initialize(m_ap.sampleRate(), m_ap.channels(), m_ap.format()))
     {
         delete output;
@@ -568,6 +570,7 @@ OutputWriter *QmmpAudioEngine::createOutput()
 void QmmpAudioEngine::prepareEffects(Decoder *d)
 {
     m_ap = d->audioParameters();
+    m_replayGain->setFormat(m_ap.format());
 
     foreach(Effect *e, m_effects) //remove disabled and external effects
     {
