@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef QMMPSETTINGS_H
@@ -42,7 +42,7 @@ public:
     /*!
      * Destructor.
      */
-    ~QmmpSettings();
+    virtual ~QmmpSettings();
     /*!
      * This enum describes possible replaygain modes.
      */
@@ -140,6 +140,11 @@ public:
      * Changes equalizer settings to \b settings
      */
     void setEqSettings(const EqSettings &settings);
+    /*!
+     * Reads equalizer settings. Call this function before equalizer usage.
+     * @param bands Number of bands.
+     */
+    void readEqSettings(int bands = EqSettings::EQ_BANDS_10);
     /*!
      * Returns buffer size in milliseconds
      */
@@ -149,6 +154,16 @@ public:
      * @param msec Buffer size in milliseconds
      */
     void setBufferSize(int msec);
+    /*!
+     * Enables/Desables file type determination by content
+     * @param enabled State of the content based type determination
+     * (\b true - enabled, \b false - disabled)
+     */
+    void setDetermineFileTypeByContent(bool enabled);
+    /*!
+     * Return \b true if content based file type determination is enabled. Otherwise returns \b false.
+     */
+    bool determineFileTypeByContent() const;
     /*!
      * Returns a pointer to the QmmpSettings instance.
      */
@@ -176,7 +191,10 @@ signals:
      */
     void eqSettingsChanged();
 
-private slots:
+public slots:
+    /*!
+     * Writes all unsaved settings to configuration file
+     */
     void sync();
 
 private:
@@ -201,6 +219,8 @@ private:
     EqSettings m_eq_settings;
     //buffer size
     int m_buffer_size;
+    //file type determination
+    bool m_determine_by_content;
 
     static QmmpSettings* m_instance;
 
