@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QIODevice>
@@ -23,12 +23,13 @@
 #include <QApplication>
 #include <QSettings>
 #include <QDir>
-#include "qmmpaudioengine.h"
+#include "qmmpevents_p.h"
+#include "qmmpaudioengine_p.h"
 #include "decoderfactory.h"
 #include "effect.h"
 #include "statehandler.h"
 #include "inputsource.h"
-#include "volumecontrol.h"
+#include "volumecontrol_p.h"
 #include "enginefactory.h"
 #include "metadatamanager.h"
 #include "qmmpsettings.h"
@@ -39,81 +40,73 @@ SoundCore *SoundCore::m_instance = 0;
 SoundCore::SoundCore(QObject *parent)
         : QObject(parent)
 {
+    if(m_instance)
+        qFatal("SoundCore: only one instance is allowed");
     m_instance = this;
-    m_decoder = 0;
-    m_error = false;
-    m_parentWidget = 0;
     m_engine = 0;
-    m_pendingEngine = 0;
-    m_volumeControl = 0;
+    m_nextState = NO_ENGINE;
     m_handler = new StateHandler(this);
+    m_volumeControl = new VolumeControl(this);
     connect(m_handler, SIGNAL(elapsedChanged(qint64)), SIGNAL(elapsedChanged(qint64)));
     connect(m_handler, SIGNAL(bitrateChanged(int)), SIGNAL(bitrateChanged(int)));
     connect(m_handler, SIGNAL(frequencyChanged(quint32)), SIGNAL(frequencyChanged(quint32)));
-    connect(m_handler, SIGNAL(precisionChanged(int)), SIGNAL(precisionChanged(int)));
+    connect(m_handler, SIGNAL(sampleSizeChanged(int)), SIGNAL(sampleSizeChanged(int)));
     connect(m_handler, SIGNAL(channelsChanged(int)), SIGNAL(channelsChanged(int)));
-    connect(m_handler, SIGNAL(metaDataChanged ()), SIGNAL(metaDataChanged ()));
-    connect(m_handler, SIGNAL(stateChanged (Qmmp::State)), SIGNAL(stateChanged(Qmmp::State)));
-    connect(m_handler, SIGNAL(stateChanged (Qmmp::State)), SLOT(startPendingEngine()));
-    connect(m_handler, SIGNAL(nextTrackRequest()), SIGNAL(nextTrackRequest()));
     connect(m_handler, SIGNAL(bufferingProgress(int)), SIGNAL(bufferingProgress(int)));
-    updateVolume();
     connect(QmmpSettings::instance(), SIGNAL(eqSettingsChanged()), SIGNAL(eqSettingsChanged()));
-    connect(QmmpSettings::instance(), SIGNAL(audioSettingsChanged()), SLOT(updateVolume()));
+    connect(QmmpSettings::instance(), SIGNAL(audioSettingsChanged()), m_volumeControl, SLOT(reload()));
+    connect(m_volumeControl, SIGNAL(volumeChanged(int, int)), SIGNAL(volumeChanged(int, int)));
 }
 
 SoundCore::~SoundCore()
 {
     stop();
     MetaDataManager::destroy();
+    m_instance = 0;
 }
 
 bool SoundCore::play(const QString &source, bool queue, qint64 offset)
 {
     if(!queue)
         stop();
-    else
-    {
-        qDeleteAll(m_pendingSources);
-        m_pendingSources.clear();
-        if(m_pendingEngine)
-            delete m_pendingEngine;
-        m_pendingEngine = 0;
-    }
+
     MetaDataManager::instance(); //create metadata manager
 
     InputSource *s = InputSource::create(source, this);
     s->setOffset(offset);
-    m_pendingSources.append(s);
-    if(state() == Qmmp::Stopped)
-        m_handler->dispatch(Qmmp::Buffering);
-    connect(s, SIGNAL(ready()), SLOT(enqueue()));
-    connect(s, SIGNAL(error()), SLOT(enqueue()));
-    bool ok = s->initialize();
-    if(!ok)
+    m_sources.enqueue(s);
+
+    connect(s, SIGNAL(ready()), SLOT(startNextSource()));
+    connect(s, SIGNAL(error()), SLOT(startNextSource()));
+
+    if(!s->initialize())
     {
-        m_pendingSources.removeAll(s);
+        m_sources.removeAll(s);
         s->deleteLater();
         if(m_handler->state() == Qmmp::Stopped || m_handler->state() == Qmmp::Buffering)
-            m_handler->dispatch(Qmmp::NormalError);
+                m_handler->dispatch(Qmmp::NormalError);
+        return false;
     }
-    return ok;
+    if(m_handler->state() == Qmmp::Stopped)
+        m_handler->dispatch(Qmmp::Buffering);
+    return true;
 }
 
 void SoundCore::stop()
 {
+    qApp->sendPostedEvents(this, 0);
     m_url.clear();
-    if(m_pendingEngine)
-        delete m_pendingEngine;
-    m_pendingEngine = 0;
     if(m_engine)
     {
         m_engine->stop();
-        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+        qApp->sendPostedEvents(this, 0);
+        //m_engine->deleteLater();
+        //m_engine = 0;
     }
-    qDeleteAll(m_pendingSources);
-    m_pendingSources.clear();
-    updateVolume();
+    qDeleteAll(m_sources);
+    m_sources.clear();
+    m_nextState = NO_ENGINE;
+    m_volumeControl->reload();
     if(state() == Qmmp::NormalError || state() == Qmmp::FatalError || state() == Qmmp::Buffering)
         StateHandler::instance()->dispatch(Qmmp::Stopped); //clear error and buffering state
 }
@@ -130,11 +123,16 @@ void SoundCore::seek(qint64 pos)
         m_engine->seek(pos);
 }
 
-const QString SoundCore::url()
+const QString SoundCore::url() const
 {
     return m_url;
 }
 
+bool SoundCore::nextTrackAccepted() const
+{
+    return m_nextState == SAME_ENGINE;
+}
+
 qint64 SoundCore::totalTime() const
 {
     return  (m_engine) ? m_engine->totalTime() : 0;
@@ -167,18 +165,6 @@ int SoundCore::rightVolume()
     return m_volumeControl->right();
 }
 
-void SoundCore::updateVolume()
-{
-    if (m_engine)
-        m_engine->mutex()->lock();
-    if(m_volumeControl)
-        delete m_volumeControl;
-    m_volumeControl = VolumeControl::create(this);
-    connect(m_volumeControl, SIGNAL(volumeChanged(int, int)), SIGNAL(volumeChanged(int, int)));
-    if (m_engine)
-        m_engine->mutex()->unlock();
-}
-
 qint64 SoundCore::elapsed()
 {
     return m_handler->elapsed();
@@ -194,9 +180,9 @@ quint32 SoundCore::frequency()
     return m_handler->frequency();
 }
 
-int SoundCore::precision() //TODO rename
+int SoundCore::sampleSize()
 {
-    return m_handler->precision();
+    return m_handler->sampleSize();
 }
 
 int SoundCore::channels()
@@ -209,119 +195,105 @@ Qmmp::State SoundCore::state() const
     return m_handler->state();
 }
 
-QMap <Qmmp::MetaData, QString> SoundCore::metaData()
+QMap <Qmmp::MetaData, QString> SoundCore::metaData() const
 {
-    return m_handler->metaData();
+    return m_metaData;
 }
 
-QString SoundCore::metaData(Qmmp::MetaData key)
+QString SoundCore::metaData(Qmmp::MetaData key) const
 {
-    return m_handler->metaData(key);
+    return m_metaData[key];
 }
 
-bool SoundCore::enqueue()
+QHash<QString, QString> SoundCore::streamInfo() const
 {
-    InputSource *s = qobject_cast<InputSource*>(sender());
-    if(!s)
-    {
-        qWarning("SoundCore: unknown signal source");
-        return false;
-    }
+    return m_streamInfo;
+}
 
-    m_pendingSources.removeAll(s);
+void SoundCore::startNextSource()
+{
+    if(m_sources.isEmpty())
+        return;
+
+    InputSource *s = m_sources.dequeue();
     m_url = s->url();
 
-    if(s->ioDevice())
+    if(s->ioDevice() && !s->ioDevice()->isOpen() && !s->ioDevice()->open(QIODevice::ReadOnly))
     {
-        bool ok = s->ioDevice()->open(QIODevice::ReadOnly);
-        if(!ok)
-        {
-            qWarning("SoundCore: input error: %s", qPrintable(s->ioDevice()->errorString()));
-            m_url.clear();
-            s->deleteLater();
-            if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
-            {
-                m_handler->dispatch(Qmmp::NormalError);
-            }
-            else
-                m_error = true;
-            return false;
-        }
+        qWarning("SoundCore: input error: %s", qPrintable(s->ioDevice()->errorString()));
+        m_url.clear();
+        s->deleteLater();
+        m_nextState = INVALID_SOURCE;
+        if(m_handler->state() == Qmmp::Stopped || m_handler->state() == Qmmp::Buffering)
+            m_handler->dispatch(Qmmp::NormalError);
+        return;
     }
 
     if(!m_engine)
     {
         if((m_engine = AbstractEngine::create(s, this)))
         {
-            connect(m_engine, SIGNAL(playbackFinished()), SIGNAL(finished()));
             m_engine->play();
-            m_handler->setCurrentEngine(m_engine);
-            return true;
+            m_nextState = NO_ENGINE;
+            return;
         }
         else
         {
             s->deleteLater();
-            m_handler->setCurrentEngine(0);
             m_handler->dispatch(Qmmp::NormalError);
-            return false;
+            return;
         }
     }
-
-    if(m_engine->enqueue(s))
+    else if(m_engine->enqueue(s))
     {
         if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
+        {
             m_engine->play();
+            m_nextState = NO_ENGINE;
+        }
         else
-            m_handler->setNextEngine(m_engine);
-        m_handler->setCurrentEngine(m_engine);
+        {
+            m_nextState = SAME_ENGINE;
+        }
     }
     else
     {
-        AbstractEngine *engine = AbstractEngine::create(s, this);
-        if(!engine)
+        m_sources.prepend(s); //try next engine
+        m_nextState = ANOTHER_ENGINE;
+        if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
         {
-            s->deleteLater();
-            m_handler->setCurrentEngine(0);
-            if(state() == Qmmp::Stopped || state() == Qmmp::Buffering)
-                m_handler->dispatch(Qmmp::NormalError);
-            else
-                m_error = true;
-            return false;
-        }
-        connect(engine, SIGNAL(playbackFinished()), SIGNAL(finished()));
-        if (m_handler->state() == Qmmp::Playing || m_handler->state() == Qmmp::Paused)
-        {
-            if(m_pendingEngine)
-                m_pendingEngine->deleteLater();
-            m_pendingEngine = engine;
-            m_handler->setNextEngine(engine);
-        }
-        else
-        {
-            m_engine->deleteLater();
-            m_engine = engine;
-            m_engine->play();
-            m_handler->setCurrentEngine(m_engine);
-            m_pendingEngine = 0;
+            startNextEngine();
         }
     }
-    return true;
 }
 
-void SoundCore::startPendingEngine()
+void SoundCore::startNextEngine()
 {
-    if(state() == Qmmp::Stopped && m_pendingEngine)
+    switch(m_nextState)
     {
-        if(m_engine)
-            delete m_engine;
-        m_engine = m_pendingEngine;
-        m_pendingEngine = 0;
-        m_engine->play();
-        m_handler->setCurrentEngine(m_engine);
+    case NO_ENGINE:
+    case SAME_ENGINE:
+    {
+        if(m_sources.isEmpty())
+            m_nextState = NO_ENGINE;
+        break;
     }
-    else if(state() == Qmmp::Stopped && m_error)
+    case ANOTHER_ENGINE:
     {
-        m_error = false;
+        m_nextState = NO_ENGINE;
+        if(m_engine)
+        {
+            m_engine->deleteLater();
+            m_engine = 0;
+        }
+        if(!m_sources.isEmpty())
+        {
+            m_handler->dispatch(Qmmp::Buffering);
+            startNextSource();
+        }
+        break;
+    }
+    case INVALID_SOURCE:
         m_handler->dispatch(Qmmp::NormalError);
     }
 }
@@ -330,3 +302,34 @@ SoundCore* SoundCore::instance()
 {
     return m_instance;
 }
+
+bool SoundCore::event(QEvent *e)
+{
+    if(e->type() == EVENT_STATE_CHANGED)
+    {
+        Qmmp::State st = ((StateChangedEvent *) e)->currentState();
+        emit stateChanged(st);
+        if(st == Qmmp::Stopped)
+        {
+            m_streamInfo.clear();
+            startNextEngine();
+        }
+    }
+    else if(e->type() == EVENT_METADATA_CHANGED)
+    {
+        m_metaData = ((MetaDataChangedEvent *) e)->metaData();
+        emit metaDataChanged();
+    }
+    else if(e->type() == EVENT_STREAM_INFO_CHANGED)
+    {
+        m_streamInfo = ((StreamInfoChangedEvent *) e)->streamInfo();
+        emit streamInfoChanged();
+    }
+    else if(e->type() == EVENT_NEXT_TRACK_REQUEST)
+        emit nextTrackRequest();
+    else if(e->type() == EVENT_FINISHED)
+        emit finished();
+    else
+        return QObject::event(e);
+    return true;
+}
