@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,12 +15,13 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QStringList>
-
+#include <QApplication>
 #include "soundcore.h"
+#include "qmmpevents_p.h"
 #include "statehandler.h"
 
 #define TICK_INTERVAL 250
@@ -31,8 +32,9 @@ StateHandler* StateHandler::m_instance = 0;
 StateHandler::StateHandler(QObject *parent)
         : QObject(parent), m_mutex(QMutex::Recursive)
 {
-    if (!m_instance)
-        m_instance = this;
+    if(m_instance)
+        qFatal("StateHandler: only one instance is allowed");
+    m_instance = this;
     m_elapsed = -1;
     m_bitrate = 0;
     m_frequency = 0;
@@ -40,23 +42,15 @@ StateHandler::StateHandler(QObject *parent)
     m_channels = 0;
     m_sendAboutToFinish = true;
     m_state = Qmmp::Stopped;
-    m_next_engine = 0;
-    m_current_engine = 0;
-    //m_mutex = QMutex(QMutex::Recursive);
 }
 
 
 StateHandler::~StateHandler()
 {
-    if (m_instance == this)
-        m_instance = 0;
+    m_instance = 0;
 }
 
-void StateHandler::dispatch(qint64 elapsed,
-                            int bitrate,
-                            quint32 frequency,
-                            int precision,
-                            int channels)
+void StateHandler::dispatch(qint64 elapsed, int bitrate, quint32 frequency, int precision, int channels)
 {
     m_mutex.lock();
     if (qAbs(m_elapsed - elapsed) > TICK_INTERVAL)
@@ -74,23 +68,23 @@ void StateHandler::dispatch(qint64 elapsed,
         {
             m_sendAboutToFinish = false;
             if(SoundCore::instance()->totalTime() - m_elapsed > PREFINISH_TIME/2)
-                emit nextTrackRequest();
+                qApp->postEvent(parent(), new QEvent(EVENT_NEXT_TRACK_REQUEST));
         }
     }
     if (m_frequency != frequency)
     {
         m_frequency = frequency;
-        emit (frequencyChanged(frequency));
+        emit frequencyChanged(frequency);
     }
     if (m_precision != precision)
     {
         m_precision = precision;
-        emit (precisionChanged(precision));
+        emit sampleSizeChanged(precision);
     }
     if (m_channels != channels)
     {
         m_channels = channels;
-        emit (channelsChanged(channels));
+        emit channelsChanged(channels);
     }
     m_mutex.unlock();
 }
@@ -110,17 +104,38 @@ void StateHandler::dispatch(const QMap<Qmmp::MetaData, QString> &metaData)
         m_mutex.unlock();
         return;
     }
-    if (m_state == Qmmp::Playing &&
-        (m_metaData.isEmpty() || m_metaData.value(Qmmp::URL) == metaData.value(Qmmp::URL)))
+    if(m_state != Qmmp::Playing && m_state != Qmmp::Paused)
+    {
+        qWarning("StateHandler: metadata is ignored");
+        m_mutex.unlock();
+        return;
+    }
+
+    if(m_metaData.isEmpty() || m_metaData.value(Qmmp::URL) == metaData.value(Qmmp::URL))
     {
         if (m_metaData != tmp)
         {
             m_metaData = tmp;
-            emit metaDataChanged ();
+            qApp->postEvent(parent(), new MetaDataChangedEvent(m_metaData));
         }
     }
-    else
-        m_cachedMetaData = tmp;
+    m_mutex.unlock();
+}
+
+void StateHandler::dispatch(const QHash<QString, QString> &info)
+{
+    m_mutex.lock();
+    QHash<QString, QString> tmp = info;
+    foreach(QString value, tmp.values()) //remove empty keys
+    {
+        if (value.isEmpty())
+            tmp.remove(tmp.key(value));
+    }
+    if(m_streamInfo != tmp)
+    {
+        m_streamInfo = tmp;
+        qApp->postEvent(parent(), new StreamInfoChangedEvent(m_streamInfo));
+    }
     m_mutex.unlock();
 }
 
@@ -137,8 +152,8 @@ void StateHandler::dispatch(Qmmp::State state)
         m_frequency = 0;
         m_precision = 0;
         m_channels = 0;
-        m_next_engine = 0;
         m_metaData.clear();
+        m_streamInfo.clear();
         m_sendAboutToFinish = true;
     }
     if (m_state != state)
@@ -147,15 +162,9 @@ void StateHandler::dispatch(Qmmp::State state)
         states << "Playing" << "Paused" << "Stopped" << "Buffering" << "NormalError" << "FatalError";
         qDebug("StateHandler: Current state: %s; previous state: %s",
                qPrintable(states.at(state)), qPrintable(states.at(m_state)));
+        Qmmp::State prevState = state;
         m_state = state;
-        emit stateChanged(state);
-        if(m_state == Qmmp::Playing && !m_cachedMetaData.isEmpty())
-        {
-            m_mutex.unlock();
-            dispatch(m_cachedMetaData);
-            m_mutex.lock();
-            m_cachedMetaData.clear();
-        }
+        qApp->postEvent(parent(), new StateChangedEvent(m_state, prevState));
     }
     m_mutex.unlock();
 }
@@ -166,16 +175,6 @@ void StateHandler::dispatchBuffer(int percent)
         emit bufferingProgress(percent);
 }
 
-void StateHandler::setNextEngine(AbstractEngine *engine)
-{
-    m_next_engine = engine;
-}
-
-void StateHandler::setCurrentEngine(AbstractEngine *engine)
-{
-    m_current_engine = engine;
-}
-
 qint64 StateHandler::elapsed()
 {
     return m_elapsed;
@@ -191,7 +190,7 @@ int StateHandler::frequency()
     return m_frequency;
 }
 
-int StateHandler::precision()
+int StateHandler::sampleSize()
 {
     return m_precision;
 }
@@ -206,35 +205,20 @@ Qmmp::State StateHandler::state() const
     return m_state;
 }
 
-QMap<Qmmp::MetaData, QString> StateHandler::metaData()
-{
-    return m_metaData;
-}
-
-QString StateHandler::metaData(Qmmp::MetaData key)
-{
-    return m_metaData.value(key);
-}
-
 void StateHandler::sendNextTrackRequest()
 {
     m_mutex.lock();
     if(m_sendAboutToFinish)
     {
         m_sendAboutToFinish = false;
-        emit nextTrackRequest();
+        qApp->postEvent(parent(), new QEvent(EVENT_NEXT_TRACK_REQUEST));
     }
     m_mutex.unlock();
 }
 
-AbstractEngine *StateHandler::nextEngine()
+void StateHandler::sendFinished()
 {
-    return m_next_engine;
-}
-
-AbstractEngine *StateHandler::currentEngine()
-{
-    return m_current_engine;
+    qApp->postEvent(parent(), new QEvent(EVENT_FINISHED));
 }
 
 StateHandler *StateHandler::instance()
