@@ -185,6 +185,8 @@ void Visual::showSettings(VisualFactory *factory, QWidget *parent)
         remove(visual);
         visual->close();
         visual = factory->create(m_parentWidget);
+        if (m_receiver && m_member)
+            connect(visual, SIGNAL(closedByUser()), m_receiver, m_member);
         visual->setWindowFlags(Qt::Window);
         m_vis_map[factory] = visual;
         visual->show();
@@ -207,7 +209,7 @@ void Visual::checkFactories()
             QPluginLoader loader(pluginsDir.absoluteFilePath(fileName));
             QObject *plugin = loader.instance();
             if (loader.isLoaded())
-                qDebug("Visual: plugin loaded - %s", qPrintable(fileName));
+                qDebug("Visual: loaded plugin %s", qPrintable(fileName));
             else
                 qWarning("Visual: %s", qPrintable(loader.errorString ()));
 
