@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QTimer>
@@ -23,7 +23,7 @@
 #include <QSettings>
 #include "qmmpsettings.h"
 #include "output.h"
-#include "volumecontrol.h"
+#include "volumecontrol_p.h"
 
 VolumeControl::VolumeControl(QObject *parent)
         : QObject(parent)
@@ -31,25 +31,16 @@ VolumeControl::VolumeControl(QObject *parent)
     m_left = 0;
     m_right = 0;
     m_prev_block = false;
+    m_volume = 0;
+    m_timer = new QTimer(this);
+    connect(m_timer, SIGNAL(timeout()), SLOT(checkVolume()));
+    reload();
 }
 
 VolumeControl::~VolumeControl()
 {
-}
-
-VolumeControl *VolumeControl::create(QObject *parent)
-{
-    if(QmmpSettings::instance()->useSoftVolume())
-        return new SoftwareVolume(parent);
-    VolumeControl *control = 0;
-    if (Output::currentFactory())
-        control = Output::currentFactory()->createVolumeControl(parent);
-    if (!control)
-        return new SoftwareVolume(parent);
-    QTimer *m_timer = new QTimer(control);
-    connect(m_timer, SIGNAL(timeout()), control, SLOT(checkVolume()));
-    m_timer->start(125);
-    return control;
+    if(m_volume)
+        delete m_volume;
 }
 
 int VolumeControl::left()
@@ -57,6 +48,15 @@ int VolumeControl::left()
     return m_left;
 }
 
+void VolumeControl::setVolume(int left, int right)
+{
+    VolumeSettings v;
+    v.left = left;
+    v.right = right;
+    m_volume->setVolume(v);
+    checkVolume();
+}
+
 int VolumeControl::right()
 {
     return m_right;
@@ -64,8 +64,10 @@ int VolumeControl::right()
 
 void VolumeControl::checkVolume()
 {
-    int l = 0, r = 0;
-    volume(&l, &r);
+    VolumeSettings v = m_volume->volume();
+    int l = v.left;
+    int r = v.right;
+
     l = (l > 100) ? 100 : l;
     r = (r > 100) ? 100 : r;
     l = (l < 0) ? 0 : l;
@@ -81,18 +83,36 @@ void VolumeControl::checkVolume()
     m_prev_block = signalsBlocked ();
 }
 
+void VolumeControl::reload()
+{
+    m_timer->stop();
+    if(m_volume)
+    {
+        delete m_volume;
+        m_volume = 0;
+    }
+    if(!QmmpSettings::instance()->useSoftVolume() && Output::currentFactory())
+    {
+        if((m_volume = Output::currentFactory()->createVolume()))
+            m_timer->start(150);
+    }
+    if(!m_volume)
+    {
+        m_volume = new SoftwareVolume;
+        blockSignals(true);
+        checkVolume();
+        blockSignals(false);
+        QTimer::singleShot(125, this, SLOT(checkVolume()));
+    }
+}
+
 SoftwareVolume *SoftwareVolume::m_instance = 0;
 
-SoftwareVolume::SoftwareVolume(QObject *parent)
-        : VolumeControl(parent)
+SoftwareVolume::SoftwareVolume()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     m_left = settings.value("Volume/left", 80).toInt();
     m_right = settings.value("Volume/right", 80).toInt();
-    blockSignals(true);
-    checkVolume();
-    blockSignals(false);
-    QTimer::singleShot(125, this, SLOT(checkVolume()));
     m_scaleLeft = (double)m_left/100.0;
     m_scaleRight = (double)m_right/100.0;
     m_instance = this;
@@ -106,24 +126,27 @@ SoftwareVolume::~SoftwareVolume()
     m_instance = 0;
 }
 
-void SoftwareVolume::setVolume(int left, int right)
+void SoftwareVolume::setVolume(const VolumeSettings &v)
 {
-    m_left = left;
-    m_right = right;
-    checkVolume();
+    m_left = v.left;
+    m_right = v.right;
     m_scaleLeft = (double)m_left/100.0;
     m_scaleRight = (double)m_right/100.0;
 }
 
-void SoftwareVolume::volume(int *left, int *right)
+VolumeSettings SoftwareVolume::volume() const
 {
-    *left = m_left;
-    *right = m_right;
+    VolumeSettings v;
+    v.left = m_left;
+    v.right = m_right;
+    return v;
 }
 
 void SoftwareVolume::changeVolume(Buffer *b, int chan, Qmmp::AudioFormat format)
 {
     int samples = 0;
+    qint32 sample1 = 0;
+    qint32 sample2 = 0;
     switch(format)
     {
     case Qmmp::PCM_S8:
@@ -158,6 +181,41 @@ void SoftwareVolume::changeVolume(Buffer *b, int chan, Qmmp::AudioFormat format)
         }
         break;
     case Qmmp::PCM_S24LE:
+        samples = b->nbytes/4;
+        if (chan > 1)
+        {
+            for (qint64 i = 0; i < samples; i+=2)
+            {
+                sample1 = ((qint32*)b->data)[i];
+                sample2 = ((qint32*)b->data)[i+1];
+
+                if (sample1 & 0x800000)
+                    sample1 |= 0xff000000;
+
+                if (sample2 & 0x800000)
+                    sample2 |= 0xff000000;
+
+                sample1 *= m_scaleLeft;
+                sample2 *= m_scaleRight;
+
+                ((qint32*)b->data)[i] = sample1;
+                ((qint32*)b->data)[i+1] = sample2;
+            }
+        }
+        else
+        {
+            for (qint64 i = 0; i < samples; i++)
+            {
+                sample1 = ((qint32*)b->data)[i];
+                sample1 *= qMax(m_scaleRight, m_scaleLeft);
+
+                if (sample1 & 0x800000)
+                    sample1 |= 0xff000000;
+
+                ((qint32*)b->data)[i] = sample1;
+            }
+        }
+        break;
     case Qmmp::PCM_S32LE:
         samples = b->nbytes/4;
         if (chan > 1)
