@@ -15,16 +15,18 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <qmmp/metadatamanager.h>
-#include "fileloader.h"
-#include "playlistsettings.h"
+#include <QRegExp>
+#include "fileloader_p.h"
+#include "qmmpuisettings.h"
 #include "playlistitem.h"
 
 FileLoader::FileLoader(QObject *parent) : QThread(parent)
 {
+    m_settings = QmmpUiSettings::instance();
     m_finished = false;
 }
 
@@ -33,7 +35,7 @@ FileLoader::~FileLoader()
 
 void FileLoader::addFile(const QString &path)
 {
-    bool use_meta = PlaylistSettings::instance()->useMetadata();
+    bool use_meta = m_settings->useMetadata();
     QList <FileInfo *> playList = MetaDataManager::instance()->createPlayList(path, use_meta);
     foreach(FileInfo *info, playList)
         emit newPlayListItem(new PlayListItem(info));
@@ -47,7 +49,8 @@ void FileLoader::addDirectory(const QString& s)
     QFileInfoList l = dir.entryInfoList(m_filters);
     foreach(QFileInfo info, l)
     {
-        addFile(info.absoluteFilePath ());
+        if(checkRestrictFilters(info) && checkExcludeFilters(info))
+            addFile(info.absoluteFilePath ());
         if (m_finished) return;
     }
     dir.setFilter(QDir::Dirs | QDir::NoDotAndDotDot);
@@ -84,24 +87,23 @@ void FileLoader::run()
 void FileLoader::loadFile(const QString &path)
 {
     m_files.enqueue(path);
-    if(m_filters.isEmpty())
-        m_filters = MetaDataManager::instance()->nameFilters();
+    MetaDataManager::instance()->prepareForAnotherThread();
+    m_filters = MetaDataManager::instance()->nameFilters();
     start(QThread::IdlePriority);
 }
 
 void FileLoader::loadFiles(const QStringList &paths)
 {
     m_files << paths;
-    if(m_filters.isEmpty())
-        m_filters = MetaDataManager::instance()->nameFilters();
+    MetaDataManager::instance()->prepareForAnotherThread();
+    m_filters = MetaDataManager::instance()->nameFilters();
     start(QThread::IdlePriority);
 }
 
 void FileLoader::loadDirectory(const QString &path)
 {
     m_directories.enqueue(path);
-    if(m_filters.isEmpty())
-        m_filters = MetaDataManager::instance()->nameFilters();
+    m_filters = MetaDataManager::instance()->nameFilters();
     start(QThread::IdlePriority);
 }
 
@@ -112,3 +114,31 @@ void FileLoader::finish()
     m_directories.clear();
     wait();
 }
+
+bool FileLoader::checkRestrictFilters(const QFileInfo &info)
+{
+    if(m_settings->restrictFilters().isEmpty())
+        return true;
+
+    foreach(QString filter, m_settings->restrictFilters())
+    {
+        QRegExp regexp (filter, Qt::CaseInsensitive, QRegExp::Wildcard);
+        if(regexp.exactMatch(info.absoluteFilePath()))
+            return true;
+    }
+    return false;
+}
+
+bool FileLoader::checkExcludeFilters(const QFileInfo &info)
+{
+    if(m_settings->excludeFilters().isEmpty())
+        return true;
+
+    foreach(QString filter, m_settings->excludeFilters())
+    {
+        QRegExp regexp (filter, Qt::CaseInsensitive, QRegExp::Wildcard);
+        if(regexp.exactMatch(info.absoluteFilePath()))
+            return false;
+    }
+    return true;
+}
