@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QApplication>
@@ -23,15 +23,16 @@
 #include <QTranslator>
 #include <QLocale>
 #include "playlistitem.h"
+#include "qmmpuisettings.h"
 #include "mediaplayer.h"
 
-#define MAX_ERRORS 4
-
 MediaPlayer *MediaPlayer::m_instance = 0;
 
 MediaPlayer::MediaPlayer(QObject *parent)
         : QObject(parent)
 {
+    if(m_instance)
+        qFatal("StateHandler: only one instance is allowed");
     m_instance = this;
     m_pl_manager = 0;
     m_core = 0;
@@ -42,29 +43,25 @@ MediaPlayer::MediaPlayer(QObject *parent)
     QString locale = Qmmp::systemLanguageID();
     translator->load(QString(":/libqmmpui_") + locale);
     qApp->installTranslator(translator);
+    m_core = new SoundCore(this);
+    m_settings = new QmmpUiSettings(this);
+    m_pl_manager = new PlayListManager(this);
+    connect(m_core, SIGNAL(nextTrackRequest()), SLOT(updateNextUrl()));
+    connect(m_core, SIGNAL(finished()), SLOT(playNext()));
+    connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(processState(Qmmp::State)));
+    connect(m_core, SIGNAL(metaDataChanged()),SLOT(updateMetaData()));
 }
 
 MediaPlayer::~MediaPlayer()
-{}
+{
+    m_instance = 0;
+}
 
 MediaPlayer* MediaPlayer::instance()
 {
     return m_instance;
 }
 
-void MediaPlayer::initialize(SoundCore *core, PlayListManager *pl_manager)
-{
-    Q_CHECK_PTR(core);
-    Q_CHECK_PTR(pl_manager);
-    m_core = core;
-    m_pl_manager = pl_manager;
-    m_repeat = false;
-    m_noPlaylistAdvance = false;
-    connect(m_core, SIGNAL(nextTrackRequest()), SLOT(updateNextUrl()));
-    connect(m_core, SIGNAL(finished()), SLOT(playNext()));
-    connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(processState(Qmmp::State)));
-}
-
 PlayListManager *MediaPlayer::playListManager()
 {
     return m_pl_manager;
@@ -110,6 +107,7 @@ void MediaPlayer::stop()
 {
     m_core->stop();
     m_nextUrl.clear();
+    m_skips = 0;
 }
 
 void MediaPlayer::next()
@@ -122,9 +120,9 @@ void MediaPlayer::next()
 
 void MediaPlayer::previous()
 {
-    bool playPrevious = m_core->state() != Qmmp::Stopped;
+    bool playNext = m_core->state() != Qmmp::Stopped;
     stop();
-    if (m_pl_manager->currentPlayList()->previous() && playPrevious)
+    if (m_pl_manager->currentPlayList()->previous() && playNext)
         play();
 }
 
@@ -201,15 +199,17 @@ void MediaPlayer::processState(Qmmp::State state)
     switch ((int) state)
     {
     case Qmmp::NormalError:
-        stop();
-        if (m_skips <= MAX_ERRORS)
+        m_core->stop();
+        m_nextUrl.clear();
+        if (m_skips <= m_pl_manager->currentPlayList()->count())
         {
             m_skips++;
             playNext();
         }
         break;
     case Qmmp::FatalError:
-        stop();
+        m_core->stop();
+        m_nextUrl.clear();
         break;
     case Qmmp::Playing:
         m_skips = 0;
@@ -217,3 +217,23 @@ void MediaPlayer::processState(Qmmp::State state)
         ;
     }
 }
+
+void MediaPlayer::updateMetaData()
+{
+    qDebug("===== metadata ======");
+    qDebug("ARTIST = %s", qPrintable(m_core->metaData(Qmmp::ARTIST)));
+    qDebug("TITLE = %s", qPrintable(m_core->metaData(Qmmp::TITLE)));
+    qDebug("ALBUM = %s", qPrintable(m_core->metaData(Qmmp::ALBUM)));
+    qDebug("COMMENT = %s", qPrintable(m_core->metaData(Qmmp::COMMENT)));
+    qDebug("GENRE = %s", qPrintable(m_core->metaData(Qmmp::GENRE)));
+    qDebug("YEAR = %s", qPrintable(m_core->metaData(Qmmp::YEAR)));
+    qDebug("TRACK = %s", qPrintable(m_core->metaData(Qmmp::TRACK)));
+    qDebug("== end of metadata ==");
+
+    PlayListModel *pl = m_pl_manager->currentPlayList();
+    if (pl->currentItem() && pl->currentItem()->url() == m_core->metaData().value(Qmmp::URL))
+    {
+        pl->currentItem()->updateMetaData(m_core->metaData());
+        pl->doCurrentVisibleRequest();
+    }
+}
