@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright(C) 2006-2012 by Ilya Kotov                                  *
+ *   Copyright(C) 2006-2013 by Ilya Kotov                                  *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -243,6 +243,7 @@ void PlayListModel::clear()
 {
     m_loader->finish();
     m_current = 0;
+    m_currentItem = 0;
     m_stop_item = 0;
     while (!m_items.isEmpty())
     {
@@ -288,7 +289,7 @@ QStringList PlayListModel::getTimes(int b,int l)
     for (int i = b; (i < b + l) && (i < m_items.size()); ++i)
     {
         d = m_items.at(i)->length();
-        if(d > 3600)
+        if(d >= 3600)
             str += QString("%1:%2").arg(d/3600).arg(d%3600/60, 2, 10, QChar('0'));
         else
             str += QString("%1").arg(d%3600/60);
@@ -342,26 +343,29 @@ void PlayListModel::removeAt (int i)
 {
     if ((i < count()) && (i >= 0))
     {
-        PlayListItem* f = m_items.takeAt(i);
-        if(m_stop_item == f)
+        PlayListItem* item = m_items.takeAt(i);
+        m_queued_songs.removeAll(item);
+        if(m_stop_item == item)
             m_stop_item = 0;
-        m_total_length -= f->length();
+        m_total_length -= item->length();
         if (m_total_length < 0)
             m_total_length = qMin(0, m_total_length);
 
-        if (f->flag() == PlayListItem::FREE)
+        if (item->flag() == PlayListItem::FREE)
         {
-            delete f;
-            f = NULL;
+            delete item;
+            item = NULL;
         }
-        else if (f->flag() == PlayListItem::EDITING)
-            f->setFlag(PlayListItem::SCHEDULED_FOR_DELETION);
+        else if (item->flag() == PlayListItem::EDITING)
+            item->setFlag(PlayListItem::SCHEDULED_FOR_DELETION);
 
         if (m_current >= i && m_current != 0)
             m_current--;
 
         if (!m_items.isEmpty())
             m_currentItem = m_items.at(m_current);
+        else
+            m_currentItem = 0;
 
         m_play_state->prepare();
         emit listChanged();
@@ -385,20 +389,21 @@ void PlayListModel::removeSelection(bool inverted)
     {
         if (m_items.at(i)->isSelected() ^ inverted)
         {
-            PlayListItem* f = m_items.takeAt(i);
-            if(f == m_stop_item)
+            PlayListItem* item = m_items.takeAt(i);
+            m_queued_songs.removeAll(item);
+            if(item == m_stop_item)
                 m_stop_item = 0;
-            m_total_length -= f->length();
+            m_total_length -= item->length();
             if (m_total_length < 0)
                 m_total_length = 0;
 
-            if (f->flag() == PlayListItem::FREE)
+            if (item->flag() == PlayListItem::FREE)
             {
-                delete f;
-                f = NULL;
+                delete item;
+                item = NULL;
             }
-            else if (f->flag() == PlayListItem::EDITING)
-                f->setFlag(PlayListItem::SCHEDULED_FOR_DELETION);
+            else if (item->flag() == PlayListItem::EDITING)
+                item->setFlag(PlayListItem::SCHEDULED_FOR_DELETION);
 
             select_after_delete = i;
 
@@ -411,6 +416,8 @@ void PlayListModel::removeSelection(bool inverted)
 
     if (!m_items.isEmpty())
         m_currentItem = m_items.at(m_current);
+    else
+        m_currentItem = 0;
 
     if (select_after_delete >= m_items.count())
         select_after_delete = m_items.count() - 1;
@@ -579,12 +586,12 @@ void PlayListModel::addToQueue()
     emit listChanged();
 }
 
-void PlayListModel::setQueued(PlayListItem* file)
+void PlayListModel::setQueued(PlayListItem* item)
 {
-    if (isQueued(file))
-        m_queued_songs.removeAll(file);
+    if (isQueued(item))
+        m_queued_songs.removeAll(item);
     else
-        m_queued_songs.enqueue(file);
+        m_queued_songs.enqueue(item);
     emit listChanged();
 }
 
@@ -892,7 +899,10 @@ void PlayListModel::loadPlaylist(const QString &f_name)
             continue;
 
         if (QFileInfo(list.at(i)).isRelative())
-            list[i].prepend(QFileInfo(f_name).canonicalPath () + QDir::separator ());
+            list[i].prepend(QFileInfo(f_name).canonicalPath () + "/");
+
+        list[i].replace("\\","/");
+        list[i].replace("//","/");
     }
     m_loader->loadFiles(list);
     file.close();
